@@ -29,79 +29,86 @@ Our module for everything related to the Caja extension.
 """
 from __future__ import with_statement
 from __future__ import absolute_import
+from rabbitvcs.util.contextmenuitems import *
+import copy
+from rabbitvcs.services.checkerservice import StatusCheckerStub as StatusChecker
+import rabbitvcs.services.service
+from rabbitvcs.util.settings import SettingsManager
+from rabbitvcs import version as EXT_VERSION
+from rabbitvcs import gettext, get_icon_path
+from rabbitvcs.util.log import Log, reload_log_settings
+import rabbitvcs.ui.property_page
+import rabbitvcs.ui
+from rabbitvcs.util.strings import S
+from rabbitvcs.util.contextmenu import (
+    MenuBuilder,
+    MainContextMenu,
+    SEPARATOR,
+    ContextMenuConditions,
+)
+from rabbitvcs.util.decorators import timeit, disable
+from rabbitvcs.util.helper import pretty_timedelta
+from rabbitvcs.util.helper import get_file_extension, get_common_directory
+from rabbitvcs.util.helper import launch_ui_window, launch_diff_tool
+import rabbitvcs.vcs.status
+from rabbitvcs.vcs import VCS
+import pysvn
+from gi.repository import Caja, GObject, Gtk, GdkPixbuf
+from rabbitvcs.util import helper
+import datetime
+from os.path import isdir, isfile, realpath, basename, dirname
+import os.path
+import os
 from six.moves import range
 
-def log_all_exceptions(type, value, tb):
-    import sys, traceback
-    from rabbitvcs.util.log import Log
-    log = Log("rabbitvcs.util.extensions.Caja.RabbitVCS")
-    log.exception_info("Error caught by master exception hook!",
-                       (type, value, tb))
 
-    text = ''.join(traceback.format_exception(type, value,
-                                              tb, limit=None))
+def log_all_exceptions(type, value, tb):
+    import sys
+    import traceback
+    from rabbitvcs.util.log import Log
+
+    log = Log("rabbitvcs.util.extensions.Caja.RabbitVCS")
+    log.exception_info("Error caught by master exception hook!", (type, value, tb))
+
+    text = "".join(traceback.format_exception(type, value, tb, limit=None))
 
     try:
         import rabbitvcs.ui.dialog
+
         rabbitvcs.ui.dialog.ErrorNotification(text)
     except Exception as ex:
-        log.exception("Additional exception when attempting"
-                      " to display error dialog.")
+        log.exception(
+            "Additional exception when attempting" " to display error dialog."
+        )
         log.exception(ex)
         raise
 
     sys.__excepthook__(type, value, tb)
 
+
 # import sys
 # sys.excepthook = log_all_exceptions
 
-import copy
-
-import os
-import os.path
-from os.path import isdir, isfile, realpath, basename, dirname
-import datetime
-
-from rabbitvcs.util import helper
 
 sa = helper.SanitizeArgv()
-from gi.repository import Caja, GObject, Gtk, GdkPixbuf
 sa.restore()
 
-import pysvn
 
-from rabbitvcs.vcs import VCS
-import rabbitvcs.vcs.status
-
-from rabbitvcs.util.helper import launch_ui_window, launch_diff_tool
-from rabbitvcs.util.helper import get_file_extension, get_common_directory
-from rabbitvcs.util.helper import pretty_timedelta
-
-from rabbitvcs.util.decorators import timeit, disable
-
-from rabbitvcs.util.contextmenu import MenuBuilder, MainContextMenu, SEPARATOR, ContextMenuConditions
-
-from rabbitvcs.util.strings import S
-
-import rabbitvcs.ui
-import rabbitvcs.ui.property_page
-
-from rabbitvcs.util.log import Log, reload_log_settings
 log = Log("rabbitvcs.util.extensions.Caja.RabbitVCS")
 
-from rabbitvcs import gettext, get_icon_path
 _ = gettext.gettext
 
-from rabbitvcs import version as EXT_VERSION
 
-from rabbitvcs.util.settings import SettingsManager
 settings = SettingsManager()
 
-import rabbitvcs.services.service
-from rabbitvcs.services.checkerservice import StatusCheckerStub as StatusChecker
 
-class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
-                 Caja.ColumnProvider, Caja.PropertyPageProvider, GObject.GObject):
+class RabbitVCS(
+    Caja.InfoProvider,
+    Caja.MenuProvider,
+    Caja.ColumnProvider,
+    Caja.PropertyPageProvider,
+    GObject.GObject,
+):
     """
     This is the main class that implements all of our awesome features.
 
@@ -189,7 +196,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
             "scalable/actions/rabbitvcs-checkmods.svg",
             "scalable/apps/rabbitvcs.svg",
             "scalable/apps/rabbitvcs-small.svg",
-            "16x16/actions/rabbitvcs-push.png"
+            "16x16/actions/rabbitvcs-push.png",
         ]
 
         rabbitvcs_icon_path = get_icon_path()
@@ -224,26 +231,26 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                 name="RabbitVCS::status_column",
                 attribute="status",
                 label=_("RVCS Status"),
-                description=""
+                description="",
             ),
             Caja.Column(
                 name="RabbitVCS::revision_column",
                 attribute="revision",
                 label=_("RVCS Revision"),
-                description=""
+                description="",
             ),
             Caja.Column(
                 name="RabbitVCS::author_column",
                 attribute="author",
                 label=_("RVCS Author"),
-                description=""
+                description="",
             ),
             Caja.Column(
                 name="RabbitVCS::age_column",
                 attribute="age",
                 label=_("RVCS Age"),
-                description=""
-            )
+                description="",
+            ),
         )
 
     def update_file_info(self, item):
@@ -268,9 +275,11 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         enable_emblems = bool(int(settings.get("general", "enable_emblems")))
         enable_attrs = bool(int(settings.get("general", "enable_attributes")))
 
-        if not (enable_emblems or enable_attrs): return Caja.OperationResult.COMPLETE
+        if not (enable_emblems or enable_attrs):
+            return Caja.OperationResult.COMPLETE
 
-        if not self.valid_uri(item.get_uri()): return Caja.OperationResult.FAILED
+        if not self.valid_uri(item.get_uri()):
+            return Caja.OperationResult.FAILED
 
         path = self.get_local_path(item)
 
@@ -290,7 +299,8 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         # when we remove this line (detected as working copies, even though
         # they are not)? That shouldn't happen.
         is_in_a_or_a_working_copy = self.vcs_client.is_in_a_or_a_working_copy(path)
-        if not is_in_a_or_a_working_copy: return Caja.OperationResult.COMPLETE
+        if not is_in_a_or_a_working_copy:
+            return Caja.OperationResult.COMPLETE
 
         # Do our magic...
 
@@ -304,24 +314,28 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         # Need to catch exception
         for idx in range(len(self.statuses_from_callback)):
             found = (self.statuses_from_callback[idx].path) == path
-            if found: break
+            if found:
+                break
 
-        if found: # We're here because we were triggered by a callback
+        if found:  # We're here because we were triggered by a callback
             status = self.statuses_from_callback[idx]
             del self.statuses_from_callback[idx]
 
         # Don't bother the checker if we already have the info from a callback
         if not found:
-            status = \
-                self.status_checker.check_status(path,
-                                                 recurse=True,
-                                                 summary=True,
-                                                 callback=self.cb_status,
-                                                 invalidate=invalidate)
+            status = self.status_checker.check_status(
+                path,
+                recurse=True,
+                summary=True,
+                callback=self.cb_status,
+                invalidate=invalidate,
+            )
 
         # FIXME: when did this get disabled?
-        if enable_attrs: self.update_columns(item, path, status)
-        if enable_emblems: self.update_status(item, path, status)
+        if enable_attrs:
+            self.update_columns(item, path, status)
+        if enable_emblems:
+            self.update_status(item, path, status)
 
         return Caja.OperationResult.COMPLETE
 
@@ -340,8 +354,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         age = ""
         if status.date:
             age = pretty_timedelta(
-                datetime.datetime.fromtimestamp(status.date),
-                datetime.datetime.now()
+                datetime.datetime.fromtimestamp(status.date), datetime.datetime.now()
             )
 
         author = ""
@@ -352,7 +365,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
             "status": status.simple_content_status(),
             "revision": revision,
             "author": author,
-            "age": age
+            "age": age,
         }
 
         for key, value in list(values.items()):
@@ -362,7 +375,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         if status.summary in rabbitvcs.ui.STATUS_EMBLEMS:
             item.add_emblem(rabbitvcs.ui.STATUS_EMBLEMS[status.summary])
 
-    #~ @disable
+    # ~ @disable
     # @timeit
     # FIXME: this is a bottleneck. See generate_statuses() in
     # MainContextMenuConditions.
@@ -393,7 +406,8 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                 paths.append(path)
                 self.VFSFile_table[path] = item
 
-        if len(paths) == 0: return []
+        if len(paths) == 0:
+            return []
 
         # log.debug("get_file_items_full() called")
 
@@ -409,7 +423,9 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                 return menu
 
         if conditions_dict != "in-progress":
-            self.status_checker.generate_menu_conditions_async(provider, base_dir, paths, self.update_file_items)
+            self.status_checker.generate_menu_conditions_async(
+                provider, base_dir, paths, self.update_file_items
+            )
             self.items_cache[path] = "in-progress"
 
         return ()
@@ -422,7 +438,8 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                 paths.append(path)
                 self.VFSFile_table[path] = item
 
-        if len(paths) == 0: return []
+        if len(paths) == 0:
+            return []
 
         # log.debug("get_file_items() called")
 
@@ -431,10 +448,10 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
 
     def update_file_items(self, provider, base_dir, paths, conditions_dict):
         paths_str = "-".join(paths)
-        self.items_cache[paths_str] =  conditions_dict
+        self.items_cache[paths_str] = conditions_dict
         Caja.MenuProvider.emit_items_updated_signal(provider)
 
-    #~ @disable
+    # ~ @disable
     # This is useful for profiling. Rename it to "get_background_items" and then
     # rename the real function "get_background_items_real".
     def get_background_items_profile(self, window, item):
@@ -443,8 +460,8 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
         path = S(gnomevfs.get_local_path_from_uri(item.get_uri())).replace("/", ":")
 
         profile_data_file = os.path.join(
-                               helper.get_home_folder(),
-                               "checkerservice_%s.stats" % path)
+            helper.get_home_folder(), "checkerservice_%s.stats" % path
+        )
 
         prof = cProfile.Profile()
         retval = prof.runcall(self.get_background_items_real, window, item)
@@ -484,13 +501,16 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                 return menu
 
         if conditions_dict != "in-progress":
-            self.status_checker.generate_menu_conditions_async(provider, path, [path], self.update_background_items)
+            self.status_checker.generate_menu_conditions_async(
+                provider, path, [path], self.update_background_items
+            )
             self.items_cache[path] = "in-progress"
 
         return ()
 
     def get_background_items(self, window, item):
-        if not self.valid_uri(item.get_uri()): return
+        if not self.valid_uri(item.get_uri()):
+            return
         path = self.get_local_path(item)
         self.VFSFile_table[path] = item
 
@@ -501,7 +521,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
     def update_background_items(self, provider, base_dir, paths, conditions_dict):
         paths_str = "-".join(paths)
         conditions = CajaMenuConditions(conditions_dict)
-        self.items_cache[paths_str] =  conditions_dict
+        self.items_cache[paths_str] = conditions_dict
         Caja.MenuProvider.emit_items_updated_signal(provider)
 
     #
@@ -517,7 +537,8 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
 
         """
 
-        if not uri.startswith("file://"): return False
+        if not uri.startswith("file://"):
+            return False
 
         return True
 
@@ -526,7 +547,6 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
     #
 
     def rescan_after_process_exit(self, proc, paths):
-
         def do_check():
             # We'll check the paths first (these were the paths that
             # were originally passed along to the context menu).
@@ -537,16 +557,17 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
             #
             for path in paths:
                 # We're not interested in the result now, just the callback
-                self.status_checker.check_status(path,
-                                                 recurse=True,
-                                                 invalidate=True,
-                                                 callback=self.cb_status,
-                                                 summary=True)
+                self.status_checker.check_status(
+                    path,
+                    recurse=True,
+                    invalidate=True,
+                    callback=self.cb_status,
+                    summary=True,
+                )
 
         self.execute_after_process_exit(proc, do_check)
 
     def execute_after_process_exit(self, proc, func=None):
-
         def is_process_still_alive():
             log.debug("is_process_still_alive() for pid: %i" % proc.pid)
             # First we need to see if the commit process is still running
@@ -555,7 +576,7 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
 
             log.debug("%s" % retval)
 
-            still_going = (retval is None)
+            still_going = retval is None
 
             if not still_going and callable(func):
                 func()
@@ -585,7 +606,6 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
 
         self.execute_after_process_exit(proc, do_reload_settings)
 
-
     #
     # Callbacks
     #
@@ -631,18 +651,22 @@ class RabbitVCS(Caja.InfoProvider, Caja.MenuProvider,
                     paths.append(path)
                     self.VFSFile_table[path] = item
 
-        if len(paths) == 0: return []
+        if len(paths) == 0:
+            return []
 
-        label = rabbitvcs.ui.property_page.PropertyPageLabel(claim_domain=False).get_widget()
-        page = rabbitvcs.ui.property_page.PropertyPage(paths, claim_domain=False).get_widget()
+        label = rabbitvcs.ui.property_page.PropertyPageLabel(
+            claim_domain=False
+        ).get_widget()
+        page = rabbitvcs.ui.property_page.PropertyPage(
+            paths, claim_domain=False
+        ).get_widget()
 
-        ppage = Caja.PropertyPage(name='RabbitVCS::PropertyPage',
-            label=label,
-            page=page)
+        ppage = Caja.PropertyPage(
+            name="RabbitVCS::PropertyPage", label=label, page=page
+        )
 
         return [ppage]
 
-from rabbitvcs.util.contextmenuitems import *
 
 class CajaContextMenu(MenuBuilder):
     """
@@ -656,10 +680,7 @@ class CajaContextMenu(MenuBuilder):
         identifier = item.make_magic_id(id_magic)
 
         menuitem = Caja.MenuItem(
-            name=identifier,
-            label=item.make_label(),
-            tip=item.tooltip,
-            icon=item.icon
+            name=identifier, label=item.make_label(), tip=item.tooltip, icon=item.icon
         )
 
         if type(item) is MenuSeparator:
@@ -675,10 +696,12 @@ class CajaContextMenu(MenuBuilder):
     def top_level_menu(self, items):
         return items
 
+
 class CajaMenuConditions(ContextMenuConditions):
     def __init__(self, path_dict):
         self.path_dict = path_dict
 
+
 class CajaMainContextMenu(MainContextMenu):
     def get_menu(self):
         return CajaContextMenu(self.structure, self.conditions, self.callbacks).menu
