@@ -1,4 +1,17 @@
 from __future__ import absolute_import
+from rabbitvcs.util.contextmenuitems import *
+from rabbitvcs.util.contextmenu import (
+    GtkFilesContextMenuConditions,
+    GtkFilesContextMenuCallbacks,
+    MainContextMenu,
+    MainContextMenuCallbacks,
+    MenuBuilder,
+    GtkContextMenuCaller,
+)
+from rabbitvcs.vcs import create_vcs_instance
+from gi.repository import Pluma, GObject, Peas
+from gi.repository import Gtk
+
 #
 # This is a Pluma plugin to allow for RabbitVCS integration in the Pluma
 # text editor.
@@ -28,17 +41,9 @@ from rabbitvcs.util import helper
 
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk
 sa.restore()
-from gi.repository import Pluma, GObject, Peas
 
 
-from rabbitvcs.vcs import create_vcs_instance
-from rabbitvcs.util.contextmenu import GtkFilesContextMenuConditions, \
-    GtkFilesContextMenuCallbacks, MainContextMenu, MainContextMenuCallbacks, \
-    MenuBuilder, GtkContextMenuCaller
-from rabbitvcs.util.contextmenuitems import *
-
 # Menu item, insert a new item on the menu bar.
 ui_str = """<ui>
   <menubar name="MenuBar">
@@ -146,10 +151,12 @@ ui_str = """<ui>
   </menubar>
 </ui>
 """
+
+
 class RabbitVCSWindowHelper(GtkContextMenuCaller):
 
     _menu_paths = [
-#        "/MenuBar/RabbitVCSMenu",
+        #        "/MenuBar/RabbitVCSMenu",
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::RabbitVCS_Svn",
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::RabbitVCS_Svn/RabbitVCS::Commit",
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::RabbitVCS_Svn/RabbitVCS::Update",
@@ -224,7 +231,7 @@ class RabbitVCSWindowHelper(GtkContextMenuCaller):
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::RabbitVCS_Git/RabbitVCS::Apply_Patch",
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::RabbitVCS_Git/RabbitVCS::Create_Patch",
         "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::Settings",
-        "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::About"
+        "/MenuBar/ExtraMenu_1/RabbitVCSMenu/RabbitVCS::About",
     ]
 
     _default_base_dir = os.path.expanduser("~")
@@ -255,15 +262,19 @@ class RabbitVCSWindowHelper(GtkContextMenuCaller):
         # Get the GtkUIManager
         manager = self._window.get_ui_manager()
 
-        self._menubar_menu = PlumaMenu(self, self.vcs_client, self.base_dir, [self._get_document_path()])
-        self._menu_action = Gtk.Action(name="RabbitVCSMenu",
-                                       label="RabbitVCS",
-                                       tooltip=_("Excellent Version Control"),
-                                       stock_id=None)
+        self._menubar_menu = PlumaMenu(
+            self, self.vcs_client, self.base_dir, [self._get_document_path()]
+        )
+        self._menu_action = Gtk.Action(
+            name="RabbitVCSMenu",
+            label="RabbitVCS",
+            tooltip=_("Excellent Version Control"),
+            stock_id=None,
+        )
 
         self._action_group = Gtk.ActionGroup("RabbitVCSActions")
         self._action_group = self._menubar_menu.get_action_group(self._action_group)
-        self._action_group.add_action( self._menu_action )
+        self._action_group.add_action(self._menu_action)
 
         # Insert the action group
         manager.insert_action_group(self._action_group, 0)
@@ -307,7 +318,9 @@ class RabbitVCSWindowHelper(GtkContextMenuCaller):
         menu.append(separator)
         separator.show()
 
-        context_menu = PlumaMainContextMenu(self, self.vcs_client, self.base_dir, [self._get_document_path()]).get_menu()
+        context_menu = PlumaMainContextMenu(
+            self, self.vcs_client, self.base_dir, [self._get_document_path()]
+        ).get_menu()
         for context_menu_item in context_menu:
             menu.append(context_menu_item)
 
@@ -355,6 +368,7 @@ class RabbitVCSWindowHelper(GtkContextMenuCaller):
     def on_context_menu_command_finished(self):
         self.update_ui()
 
+
 class RabbitVCSPlumaPlugin(GObject.Object, Peas.Activatable):
     __gtype_name__ = "RabbitVCSPlumaPlugin"
     object = GObject.property(type=GObject.Object)
@@ -368,8 +382,8 @@ class RabbitVCSPlumaPlugin(GObject.Object, Peas.Activatable):
         self._instances[self.object] = RabbitVCSWindowHelper(self, self.object)
 
         handler_ids = []
-        for signal in ('tab-added', 'tab-removed'):
-            method = getattr(self, 'on_window_' + signal.replace('-', '_'))
+        for signal in ("tab-added", "tab-removed"):
+            method = getattr(self, "on_window_" + signal.replace("-", "_"))
             handler_ids.append(self.object.connect(signal, method))
 
         setattr(self.object, self.id_name, handler_ids)
@@ -405,16 +419,19 @@ class RabbitVCSPlumaPlugin(GObject.Object, Peas.Activatable):
         if window in self._instances:
             self._instances[window].disconnect_view(tab.get_view(), self.id_name)
 
+
 class MenuIgnoreByFilename(MenuItem):
     identifier = "RabbitVCS::Ignore_By_Filename"
     label = _("Ignore by File Name")
     tooltip = _("Ignore item by filename")
 
+
 class MenuIgnoreByFileExtension(MenuItem):
     identifier = "RabbitVCS::Ignore_By_File_Extension"
     label = _("Ignore by File Extension")
     tooltip = _("Ignore item by extension")
 
+
 class PlumaMenuBuilder(object):
     """
     Generalised menu builder class. Subclasses must provide:
@@ -493,6 +510,7 @@ class PlumaMenuBuilder(object):
 
         return function
 
+
 class PlumaMenu(object):
     def __init__(self, caller, vcs_client, base_dir, paths):
         """
@@ -523,10 +541,7 @@ class PlumaMenu(object):
         self.conditions = GtkFilesContextMenuConditions(self.vcs_client, self.paths)
 
         self.callbacks = GtkFilesContextMenuCallbacks(
-            self.caller,
-            self.base_dir,
-            self.vcs_client,
-            self.paths
+            self.caller, self.base_dir, self.vcs_client, self.paths
         )
 
         self.structure = [
@@ -583,7 +598,7 @@ class PlumaMenu(object):
             MenuSettings,
             MenuAbout,
             MenuIgnoreByFilename,
-            MenuIgnoreByFileExtension
+            MenuIgnoreByFileExtension,
         ]
 
     def set_paths(self, paths):
@@ -597,7 +612,9 @@ class PlumaMenu(object):
         self.conditions.base_dir = base_dir
 
     def get_action_group(self, action_group):
-        return PlumaMenuBuilder(self.structure, self.conditions, self.callbacks, action_group).action_group
+        return PlumaMenuBuilder(
+            self.structure, self.conditions, self.callbacks, action_group
+        ).action_group
 
     def update_conditions(self, paths):
         self.conditions.generate_statuses(paths)
@@ -606,6 +623,7 @@ class PlumaMenu(object):
     def update_action(self, action):
         action.set_property("visible", action.item.show())
 
+
 class PlumaContextMenu(MenuBuilder):
     """
     Provides a standard Gtk context menu (ie. a list of Gtk.MenuItem"s).
@@ -624,9 +642,11 @@ class PlumaContextMenu(MenuBuilder):
     def top_level_menu(self, items):
         return items
 
+
 class PlumaMainContextMenu(MainContextMenu):
-    def __init__(self, caller, vcs_client, base_dir, paths=[],
-            conditions=None, callbacks=None):
+    def __init__(
+        self, caller, vcs_client, base_dir, paths=[], conditions=None, callbacks=None
+    ):
         """
         @param  caller: The calling object
         @type   caller: RabbitVCS extension
@@ -659,10 +679,7 @@ class PlumaMainContextMenu(MainContextMenu):
         self.callbacks = callbacks
         if self.callbacks is None:
             self.callbacks = MainContextMenuCallbacks(
-                self.caller,
-                self.base_dir,
-                self.vcs_client,
-                paths
+                self.caller, self.base_dir, self.vcs_client, paths
             )
 
         ignore_items = get_ignore_list_items(paths)
@@ -674,93 +691,105 @@ class PlumaMainContextMenu(MainContextMenu):
             (MenuUpdate, None),
             (MenuCommit, None),
             (MenuPush, None),
-            (MenuRabbitVCSSvn, [
-                (MenuCheckout, None),
-                (MenuDiffMenu, [
-                    (MenuDiff, None),
-                    (MenuDiffPrevRev, None),
-                    (MenuDiffMultiple, None),
-                    (MenuCompareTool, None),
-                    (MenuCompareToolPrevRev, None),
-                    (MenuCompareToolMultiple, None),
-                    (MenuShowChanges, None),
-                ]),
-                (MenuShowLog, None),
-                (MenuRepoBrowser, None),
-                (MenuCheckForModifications, None),
-                (MenuSeparator, None),
-                (MenuAdd, None),
-                (MenuAddToIgnoreList, ignore_items),
-                (MenuSeparator, None),
-                (MenuUpdateToRevision, None),
-                (MenuRename, None),
-                (MenuDelete, None),
-                (MenuRevert, None),
-                (MenuEditConflicts, None),
-                (MenuMarkResolved, None),
-                (MenuRelocate, None),
-                (MenuGetLock, None),
-                (MenuUnlock, None),
-                (MenuCleanup, None),
-                (MenuSeparator, None),
-                (MenuExport, None),
-                (MenuCreateRepository, None),
-                (MenuImport, None),
-                (MenuSeparator, None),
-                (MenuBranchTag, None),
-                (MenuSwitch, None),
-                (MenuMerge, None),
-                (MenuSeparator, None),
-                (MenuAnnotate, None),
-                (MenuSeparator, None),
-                (MenuCreatePatch, None),
-                (MenuApplyPatch, None),
-                (MenuProperties, None),
-                (MenuSeparator, None),
-                (MenuSettings, None),
-                (MenuAbout, None)
-            ]),
-            (MenuRabbitVCSGit, [
-                (MenuClone, None),
-                (MenuInitializeRepository, None),
-                (MenuSeparator, None),
-                (MenuDiffMenu, [
-                    (MenuDiff, None),
-                    (MenuDiffPrevRev, None),
-                    (MenuDiffMultiple, None),
-                    (MenuCompareTool, None),
-                    (MenuCompareToolPrevRev, None),
-                    (MenuCompareToolMultiple, None),
-                    (MenuShowChanges, None),
-                ]),
-                (MenuShowLog, None),
-                (MenuStage, None),
-                (MenuUnstage, None),
-                (MenuAddToIgnoreList, ignore_items),
-                (MenuSeparator, None),
-                (MenuRename, None),
-                (MenuDelete, None),
-                (MenuRevert, None),
-                (MenuEditConflicts, None),
-                (MenuClean, None),
-                (MenuReset, None),
-                (MenuCheckout, None),
-                (MenuSeparator, None),
-                (MenuBranches, None),
-                (MenuTags, None),
-                (MenuRemotes, None),
-                (MenuSeparator, None),
-                (MenuExport, None),
-                (MenuMerge, None),
-                (MenuSeparator, None),
-                (MenuAnnotate, None),
-                (MenuSeparator, None),
-                (MenuCreatePatch, None),
-                (MenuApplyPatch, None),
-                (MenuSeparator, None),
-                (MenuSettings, None),
-                (MenuAbout, None)
-            ])
+            (
+                MenuRabbitVCSSvn,
+                [
+                    (MenuCheckout, None),
+                    (
+                        MenuDiffMenu,
+                        [
+                            (MenuDiff, None),
+                            (MenuDiffPrevRev, None),
+                            (MenuDiffMultiple, None),
+                            (MenuCompareTool, None),
+                            (MenuCompareToolPrevRev, None),
+                            (MenuCompareToolMultiple, None),
+                            (MenuShowChanges, None),
+                        ],
+                    ),
+                    (MenuShowLog, None),
+                    (MenuRepoBrowser, None),
+                    (MenuCheckForModifications, None),
+                    (MenuSeparator, None),
+                    (MenuAdd, None),
+                    (MenuAddToIgnoreList, ignore_items),
+                    (MenuSeparator, None),
+                    (MenuUpdateToRevision, None),
+                    (MenuRename, None),
+                    (MenuDelete, None),
+                    (MenuRevert, None),
+                    (MenuEditConflicts, None),
+                    (MenuMarkResolved, None),
+                    (MenuRelocate, None),
+                    (MenuGetLock, None),
+                    (MenuUnlock, None),
+                    (MenuCleanup, None),
+                    (MenuSeparator, None),
+                    (MenuExport, None),
+                    (MenuCreateRepository, None),
+                    (MenuImport, None),
+                    (MenuSeparator, None),
+                    (MenuBranchTag, None),
+                    (MenuSwitch, None),
+                    (MenuMerge, None),
+                    (MenuSeparator, None),
+                    (MenuAnnotate, None),
+                    (MenuSeparator, None),
+                    (MenuCreatePatch, None),
+                    (MenuApplyPatch, None),
+                    (MenuProperties, None),
+                    (MenuSeparator, None),
+                    (MenuSettings, None),
+                    (MenuAbout, None),
+                ],
+            ),
+            (
+                MenuRabbitVCSGit,
+                [
+                    (MenuClone, None),
+                    (MenuInitializeRepository, None),
+                    (MenuSeparator, None),
+                    (
+                        MenuDiffMenu,
+                        [
+                            (MenuDiff, None),
+                            (MenuDiffPrevRev, None),
+                            (MenuDiffMultiple, None),
+                            (MenuCompareTool, None),
+                            (MenuCompareToolPrevRev, None),
+                            (MenuCompareToolMultiple, None),
+                            (MenuShowChanges, None),
+                        ],
+                    ),
+                    (MenuShowLog, None),
+                    (MenuStage, None),
+                    (MenuUnstage, None),
+                    (MenuAddToIgnoreList, ignore_items),
+                    (MenuSeparator, None),
+                    (MenuRename, None),
+                    (MenuDelete, None),
+                    (MenuRevert, None),
+                    (MenuEditConflicts, None),
+                    (MenuClean, None),
+                    (MenuReset, None),
+                    (MenuCheckout, None),
+                    (MenuSeparator, None),
+                    (MenuBranches, None),
+                    (MenuTags, None),
+                    (MenuRemotes, None),
+                    (MenuSeparator, None),
+                    (MenuExport, None),
+                    (MenuMerge, None),
+                    (MenuSeparator, None),
+                    (MenuAnnotate, None),
+                    (MenuSeparator, None),
+                    (MenuCreatePatch, None),
+                    (MenuApplyPatch, None),
+                    (MenuSeparator, None),
+                    (MenuSettings, None),
+                    (MenuAbout, None),
+                ],
+            ),
         ]
 
     def get_menu(self):
