@@ -1,4 +1,18 @@
 from __future__ import absolute_import
+from six.moves import map
+from rabbitvcs import gettext
+import configobj
+import pysvn
+import rabbitvcs.ui.widget
+from rabbitvcs.ui import InterfaceView
+import rabbitvcs
+from gi.repository import Gtk, GObject, GdkPixbuf
+import gi
+from rabbitvcs.util import helper
+import re
+import string
+import os.path
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -22,28 +36,14 @@ You should have received a copy of the GNU General Public License
 along with RabbitVCS;  If not, see <http://www.gnu.org/licenses/>.  """
 
 
-import os.path
-import string
-import re
-
-from rabbitvcs.util import helper
-
-import gi
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, GdkPixbuf
 sa.restore()
 
-import rabbitvcs
-from rabbitvcs.ui import InterfaceView
-import rabbitvcs.ui.widget
-import pysvn
-import configobj
 
-from rabbitvcs import gettext
-from six.moves import map
 _ = gettext.gettext
 
+
 class About(object):
     """
     This class provides an interface to the About window.
@@ -61,6 +61,7 @@ class About(object):
 
         doc_path_root = "/usr/share/doc"
         doc_path_regex = re.compile("rabbitvcs")
+        authors_path = None
         for dir in os.listdir(doc_path_root):
             if doc_path_regex.search(dir):
                 # Find all the doc directories containing "rabbitvcs"
@@ -73,21 +74,22 @@ class About(object):
         if not authors_path:
             # Assumes the user is running RabbitVCS through an svn checkout
             # and the doc files are two directories up (from rabbitvcs/ui).
-            doc_path = os.path.dirname(os.path.realpath(__file__)).split('/')
-            doc_path = '/'.join(doc_path[:-2])
+            doc_path = os.path.dirname(os.path.realpath(__file__)).split("/")
+            doc_path = "/".join(doc_path[:-2])
             authors_path = os.path.join(doc_path, "AUTHORS")
 
         authors = open(authors_path, "r").read()
 
         self.about.set_authors(authors.split("\n"))
 
-        pixbuf = GdkPixbuf.Pixbuf.new_from_file(rabbitvcs.get_icon_path() +
-                                                "/scalable/apps/rabbitvcs.svg")
+        pixbuf = GdkPixbuf.Pixbuf.new_from_file(
+            rabbitvcs.get_icon_path() + "/scalable/apps/rabbitvcs.svg"
+        )
         self.about.set_logo(pixbuf)
 
         versions = []
-        versions.append("Subversion - %s" % ".".join(list(map(str,pysvn.svn_version))))
-        versions.append("Pysvn - %s" % ".".join(list(map(str,pysvn.version))))
+        versions.append("Subversion - %s" % ".".join(list(map(str, pysvn.svn_version))))
+        versions.append("Pysvn - %s" % ".".join(list(map(str, pysvn.version))))
         versions.append("ConfigObj - %s" % str(configobj.__version__))
 
         self.about.set_comments("\n".join(versions))
