@@ -1,4 +1,11 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+from rabbitvcs.util.log import Log
+import rabbitvcs.vcs
+from rabbitvcs.ui.action import SVNAction
+from rabbitvcs.ui import InterfaceNonView
+from gi.repository import Gtk, GObject, Gdk
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -26,21 +33,17 @@ import os.path
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk
 sa.restore()
 
-from rabbitvcs.ui import InterfaceNonView
-from rabbitvcs.ui.action import SVNAction
-import rabbitvcs.vcs
-from rabbitvcs.util.log import Log
 
 log = Log("rabbitvcs.ui.applypatch")
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
+
 class ApplyPatch(InterfaceNonView):
     """
     This class provides a handler to the apply patch functionality.
@@ -57,9 +60,8 @@ class ApplyPatch(InterfaceNonView):
         path = None
 
         dialog = Gtk.FileChooserDialog(
-            title = _("Apply Patch"),
-            parent = None,
-            action = Gtk.FileChooserAction.OPEN)
+            title=_("Apply Patch"), parent=None, action=Gtk.FileChooserAction.OPEN
+        )
         dialog.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         dialog.add_button(_("_Open"), Gtk.ResponseType.OK)
         dialog.set_default_response(Gtk.ResponseType.OK)
@@ -78,9 +80,10 @@ class ApplyPatch(InterfaceNonView):
         dir = None
 
         dialog = Gtk.FileChooserDialog(
-                title = _("Apply Patch To Directory..."),
-                parent = None,
-                action = Gtk.FileChooserAction.SELECT_FOLDER)
+            title=_("Apply Patch To Directory..."),
+            parent=None,
+            action=Gtk.FileChooserAction.SELECT_FOLDER,
+        )
         dialog.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         dialog.add_button(_("_Select"), Gtk.ResponseType.OK)
         dialog.set_default_response(Gtk.ResponseType.OK)
@@ -94,6 +97,7 @@ class ApplyPatch(InterfaceNonView):
 
         return dir
 
+
 class SVNApplyPatch(ApplyPatch):
     def __init__(self, paths):
         ApplyPatch.__init__(self, paths)
@@ -113,8 +117,7 @@ class SVNApplyPatch(ApplyPatch):
 
         ticks = 2
         self.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            register_gtk_quit=self.gtk_quit_is_set()
+            self.svn, register_gtk_quit=self.gtk_quit_is_set()
         )
         self.action.set_pbar_ticks(ticks)
         self.action.append(self.action.set_header, _("Apply Patch"))
@@ -124,6 +127,7 @@ class SVNApplyPatch(ApplyPatch):
         self.action.append(self.action.finish)
         self.action.schedule()
 
+
 class GitApplyPatch(ApplyPatch):
     def __init__(self, paths):
         ApplyPatch.__init__(self, paths)
@@ -143,8 +147,7 @@ class GitApplyPatch(ApplyPatch):
 
         ticks = 2
         self.action = rabbitvcs.ui.action.GitAction(
-            self.git,
-            register_gtk_quit=self.gtk_quit_is_set()
+            self.git, register_gtk_quit=self.gtk_quit_is_set()
         )
         self.action.set_pbar_ticks(ticks)
         self.action.append(self.action.set_header, _("Apply Patch"))
@@ -154,11 +157,13 @@ class GitApplyPatch(ApplyPatch):
         self.action.append(self.action.finish)
         self.action.schedule()
 
+
 classes_map = {
     rabbitvcs.vcs.VCS_SVN: SVNApplyPatch,
-    rabbitvcs.vcs.VCS_GIT: GitApplyPatch
+    rabbitvcs.vcs.VCS_GIT: GitApplyPatch,
 }
 
+
 def applypatch_factory(paths):
     guess = rabbitvcs.vcs.guess(paths[0])
     return classes_map[guess["vcs"]](paths)
@@ -166,10 +171,10 @@ def applypatch_factory(paths):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main
+
     (options, paths) = main(usage="Usage: rabbitvcs applypatch [path1] [path2] ...")
 
     window = applypatch_factory(paths)
     window.register_gtk_quit()
     window.start()
     Gtk.main()
-
