@@ -1,4 +1,22 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+from rabbitvcs.util.decorators import gtk_unsafe
+from rabbitvcs.util.log import Log
+from rabbitvcs.util.strings import S
+import rabbitvcs.util.settings
+import rabbitvcs.vcs
+import rabbitvcs.ui.action
+import rabbitvcs.ui.dialog
+import rabbitvcs.ui.widget
+from rabbitvcs.util.contextmenuitems import *
+from rabbitvcs.util.contextmenu import (
+    GtkContextMenu,
+    GtkContextMenuCaller,
+    GtkFilesContextMenuConditions,
+)
+from rabbitvcs.ui import InterfaceView
+from gi.repository import Gtk, GObject, Gdk
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -29,31 +47,19 @@ from datetime import datetime
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk
 sa.restore()
 
-from rabbitvcs.ui import InterfaceView
-from rabbitvcs.util.contextmenu import GtkContextMenu, GtkContextMenuCaller, \
-    GtkFilesContextMenuConditions
-from rabbitvcs.util.contextmenuitems import *
-import rabbitvcs.ui.widget
-import rabbitvcs.ui.dialog
-import rabbitvcs.ui.action
-import rabbitvcs.vcs
-import rabbitvcs.util.settings
-from rabbitvcs.util.strings import S
-from rabbitvcs.util.log import Log
-from rabbitvcs.util.decorators import gtk_unsafe
 
 log = Log("rabbitvcs.ui.browser")
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
 helper.gobject_threads_init()
 
+
 class SVNBrowser(InterfaceView, GtkContextMenuCaller):
     def __init__(self, url):
         InterfaceView.__init__(self, "browser", "Browser")
@@ -66,71 +72,62 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
 
         self.url = ""
         if self.svn.is_in_a_or_a_working_copy(url):
-            action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False, run_in_thread=False)
+            action = rabbitvcs.ui.action.SVNAction(
+                self.svn, notification=False, run_in_thread=False
+            )
             self.url = S(action.run_single(self.svn.get_repo_url, url))
         elif self.svn.is_path_repository_url(url):
             self.url = S(url)
 
         self.urls = rabbitvcs.ui.widget.ComboBox(
-            self.get_widget("urls"),
-            helper.get_repository_paths()
+            self.get_widget("urls"), helper.get_repository_paths()
         )
         if self.url:
             self.urls.set_child_text(helper.unquote_url(self.url))
 
         # We must set a signal handler for the Gtk.Entry inside the combobox
         # Because glade will not retain that information
-        self.urls.set_child_signal(
-            "key-release-event",
-            self.on_urls_key_released
-        )
+        self.urls.set_child_signal("key-release-event", self.on_urls_key_released)
 
         self.revision_selector = rabbitvcs.ui.widget.RevisionSelector(
             self.get_widget("revision_container"),
             self.svn,
             url_combobox=self.urls,
-            expand=True
+            expand=True,
         )
 
         self.items = []
         self.list_table = rabbitvcs.ui.widget.Table(
             self.get_widget("list"),
-            [rabbitvcs.ui.widget.TYPE_HIDDEN_OBJECT,
-                rabbitvcs.ui.widget.TYPE_PATH, GObject.TYPE_INT,
-                GObject.TYPE_INT, GObject.TYPE_STRING, GObject.TYPE_FLOAT],
+            [
+                rabbitvcs.ui.widget.TYPE_HIDDEN_OBJECT,
+                rabbitvcs.ui.widget.TYPE_PATH,
+                GObject.TYPE_INT,
+                GObject.TYPE_INT,
+                GObject.TYPE_STRING,
+                GObject.TYPE_FLOAT,
+            ],
             ["", _("Path"), _("Revision"), _("Size"), _("Author"), _("Date")],
-            filters=[{
-                "callback": self.file_filter,
-                "user_data": {
-                    "column": 1
-                }
-            },{
-                "callback": self.revision_filter,
-                "user_data": {
-                    "column": 2
-                }
-            },{
-                "callback": self.size_filter,
-                "user_data": {
-                    "column": 3
-                }
-            },{
-                "callback": self.date_filter,
-                "user_data": {
-                    "column": 5
-                }
-            }],
-            filter_types=[GObject.TYPE_STRING, GObject.TYPE_STRING,
-                GObject.TYPE_STRING, GObject.TYPE_STRING,
-                GObject.TYPE_STRING, GObject.TYPE_STRING],
+            filters=[
+                {"callback": self.file_filter, "user_data": {"column": 1}},
+                {"callback": self.revision_filter, "user_data": {"column": 2}},
+                {"callback": self.size_filter, "user_data": {"column": 3}},
+                {"callback": self.date_filter, "user_data": {"column": 5}},
+            ],
+            filter_types=[
+                GObject.TYPE_STRING,
+                GObject.TYPE_STRING,
+                GObject.TYPE_STRING,
+                GObject.TYPE_STRING,
+                GObject.TYPE_STRING,
+                GObject.TYPE_STRING,
+            ],
             callbacks={
                 "file-column-callback": self.file_column_callback,
                 "row-activated": self.on_row_activated,
-                "mouse-event":   self.on_list_table_mouse_event
+                "mouse-event": self.on_list_table_mouse_event,
             },
-            flags={
-                "sortable": True
-            }
+            flags={"sortable": True},
         )
 
         self.url_clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
@@ -142,15 +139,11 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
 
     def load(self):
         self.url = self.urls.get_active_text()
-        self.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
         revision = self.revision_selector.get_revision_object()
         self.action.append(
-                        self.svn.list,
-                        helper.quote_url(self.url),
-                        revision=revision, recurse=False)
+            self.svn.list, helper.quote_url(self.url), revision=revision, recurse=False
+        )
         self.action.append(self.init_repo_root_url)
         self.action.append(self.populate_table, 0)
         self.action.schedule()
@@ -159,22 +152,26 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
     def populate_table(self, item_index=0):
         self.list_table.clear()
         self.items = self.action.get_result(item_index)
-        self.items.sort(key = self.sort_files_key)
+        self.items.sort(key=self.sort_files_key)
 
         self.list_table.append([S(".."), "..", 0, 0, "", 0])
-        for item,locked in self.items[1:]:
-            self.list_table.append([
-                S(item.path),
-                item.path,
-                item.created_rev.number,
-                item.size,
-                item.last_author,
-                item.time
-            ])
+        for item, locked in self.items[1:]:
+            self.list_table.append(
+                [
+                    S(item.path),
+                    item.path,
+                    item.created_rev.number,
+                    item.size,
+                    item.last_author,
+                    item.time,
+                ]
+            )
 
     def init_repo_root_url(self):
         if self.repo_root_url is None and self.svn.is_in_a_or_a_working_copy(self.url):
-            action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False, run_in_thread=False)
+            action = rabbitvcs.ui.action.SVNAction(
+                self.svn, notification=False, run_in_thread=False
+            )
             self.repo_root_url = action.run_single(self.svn.get_repo_root_url, self.url)
 
     def on_refresh_clicked(self, widget):
@@ -183,6 +180,7 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
 
     def create_folder(self, where):
         from rabbitvcs.ui.dialog import NewFolder
+
         dialog = NewFolder()
         result = dialog.run()
         if result is None:
@@ -191,10 +189,7 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
         (folder_name, log_message) = result
         new_url = where.rstrip("/") + "/" + folder_name
 
-        self.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
         self.action.append(self.svn.mkdir, new_url, log_message)
         self.action.append(self.svn.list, where, recurse=False)
         self.action.append(self.populate_table, 1)
@@ -231,7 +226,7 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
         if filename == six.u(".."):
             return "dir"
 
-        for item,locked in self.items:
+        for item, locked in self.items:
             if S(item.path).unicode() == filename:
                 return self.svn.NODE_KINDS_REVERSE[item.kind]
         return None
@@ -309,23 +304,25 @@ class SVNBrowser(InterfaceView, GtkContextMenuCaller):
         return self.urls.get_active_text()
 
     def _open(self, paths):
-        self.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
 
         exported_paths = []
         for path in paths:
             export_path = helper.get_tmp_path(os.path.basename(paths[0]))
             exported_paths.append(export_path)
-            self.action.append(self.svn.export, paths[0],
-                export_path, revision=self.revision_selector.get_revision_object())
+            self.action.append(
+                self.svn.export,
+                paths[0],
+                export_path,
+                revision=self.revision_selector.get_revision_object(),
+            )
 
         for path in exported_paths:
             self.action.append(helper.open_item, path)
 
         self.action.schedule()
 
+
 class SVNBrowserDialog(SVNBrowser):
     def __init__(self, path, callback=None):
         """
@@ -353,23 +350,24 @@ class SVNBrowserDialog(SVNBrowser):
             self.callback(path)
 
 
-
-
 class MenuCreateRepositoryFolder(MenuItem):
     identifier = "RabbitVCS::Create_Repository_Folder"
     label = _("Create folder...")
     icon = "folder-new"
 
+
 class MenuBrowserCopyTo(MenuItem):
     identifier = "RabbitVCS::Browser_Copy_To"
     label = _("Copy to...")
     icon = "edit-copy"
 
+
 class MenuBrowserCopyUrlToClipboard(MenuItem):
     identifier = "RabbitVCS::Browser_Copy_Url_To_Clipboard"
     label = _("Copy URL to clipboard")
     icon = "rabbitvcs-asynchronous"
 
+
 class MenuBrowserMoveTo(MenuItem):
     identifier = "RabbitVCS::Browser_Move_To"
     label = _("Move to...")
@@ -395,7 +393,7 @@ class BrowserContextMenuConditions(GtkFilesContextMenuConditions):
 
     def annotate(self, data1=None, data2=None):
         if self.path_dict["length"] == 1:
-            return (self.caller.file_column_callback(self.paths[0]) == "file")
+            return self.caller.file_column_callback(self.paths[0]) == "file"
 
         return False
 
@@ -417,20 +415,21 @@ class BrowserContextMenuConditions(GtkFilesContextMenuConditions):
 
     def create_repository_folder(self, data1=None):
         if self.path_dict["length"] == 1 and not self.is_parent_selected():
-            return (self.caller.file_column_callback(self.paths[0]) == "dir")
+            return self.caller.file_column_callback(self.paths[0]) == "dir"
 
-        return (self.path_dict["length"] == 0)
+        return self.path_dict["length"] == 0
 
     def browser_copy_to(self, data1=None, data2=None):
         return not self.is_parent_selected()
 
     def browser_copy_url_to_clipboard(self, data1=None, data2=None):
-        return (self.path_dict["length"] == 1)
+        return self.path_dict["length"] == 1
 
     def browser_move_to(self, data1=None, data2=None):
         revision = self.caller.revision_selector.get_revision_object()
         return revision.kind == "head" and not self.is_parent_selected()
 
+
 class BrowserContextMenuCallbacks(object):
     def __init__(self, caller, base_dir, vcs, paths=[]):
         self.caller = caller
@@ -454,7 +453,7 @@ class BrowserContextMenuCallbacks(object):
         # Used for the copy_to menu item
         sources = []
         for path in self.paths:
-            sources.append((path,self.__get_browser_revision().primitive()))
+            sources.append((path, self.__get_browser_revision().primitive()))
 
         return sources
 
@@ -489,6 +488,7 @@ class BrowserContextMenuCallbacks(object):
         (base, filename) = os.path.split(self.paths[0])
 
         from rabbitvcs.ui.dialog import OneLineTextChange
+
         dialog = OneLineTextChange(_("Rename"), _("New Name:"), filename)
         (result, new_name) = dialog.run()
 
@@ -501,10 +501,7 @@ class BrowserContextMenuCallbacks(object):
             path_to_refresh = new_url
             self.__update_browser_url(path_to_refresh)
 
-        self.caller.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.caller.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
         self.caller.action.append(self.svn.move, self.paths[0], new_url)
         self.caller.action.append(self.svn.list, path_to_refresh, recurse=False)
         self.caller.action.append(self.caller.populate_table, 1)
@@ -519,10 +516,7 @@ class BrowserContextMenuCallbacks(object):
 
             self.__update_browser_url(path_to_refresh)
 
-        self.caller.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.caller.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
         self.caller.action.append(self.svn.remove, self.paths)
         self.caller.action.append(self.svn.list, path_to_refresh, recurse=False)
         self.caller.action.append(self.caller.populate_table, 1)
@@ -533,10 +527,11 @@ class BrowserContextMenuCallbacks(object):
 
     def browser_copy_to(self, data=None, user_data=None):
         from rabbitvcs.ui.dialog import OneLineTextChange
+
         dialog = OneLineTextChange(
             _("Where do you want to copy the selection?"),
             _("New Location:"),
-            self.caller.get_url()
+            self.caller.get_url(),
         )
         result = dialog.run()
         if result is None:
@@ -548,11 +543,10 @@ class BrowserContextMenuCallbacks(object):
 
         sources = self.__generate_sources_list()
 
-        self.caller.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
+        self.caller.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
+        self.caller.action.append(
+            self.svn.copy_all, sources, new_url, copy_as_child=True
         )
-        self.caller.action.append(self.svn.copy_all, sources, new_url, copy_as_child=True)
         self.caller.action.append(self.svn.list, self.caller.get_url(), recurse=False)
         self.caller.action.append(self.caller.populate_table, 1)
         self.caller.action.schedule()
@@ -562,10 +556,11 @@ class BrowserContextMenuCallbacks(object):
 
     def browser_move_to(self, data=None, user_data=None):
         from rabbitvcs.ui.dialog import OneLineTextChange
+
         dialog = OneLineTextChange(
             _("Where do you want to move the selection?"),
             _("New Location:"),
-            self.caller.get_url()
+            self.caller.get_url(),
         )
         result = dialog.run()
         if result is None:
@@ -575,15 +570,15 @@ class BrowserContextMenuCallbacks(object):
         if response == Gtk.ResponseType.CANCEL:
             return
 
-        self.caller.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
+        self.caller.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
+        self.caller.action.append(
+            self.svn.move_all, self.paths, new_url, move_as_child=True
         )
-        self.caller.action.append(self.svn.move_all, self.paths, new_url, move_as_child=True)
         self.caller.action.append(self.svn.list, self.caller.get_url(), recurse=False)
         self.caller.action.append(self.caller.populate_table, 1)
         self.caller.action.schedule()
 
+
 class BrowserContextMenu(object):
     def __init__(self, caller, event, base_dir, vcs, paths=[]):
 
@@ -594,16 +589,9 @@ class BrowserContextMenu(object):
         self.vcs = vcs
         self.svn = self.vcs.svn()
 
-        self.conditions = BrowserContextMenuConditions(
-            self.vcs,
-            paths,
-            self.caller
-        )
+        self.conditions = BrowserContextMenuConditions(self.vcs, paths, self.caller)
         self.callbacks = BrowserContextMenuCallbacks(
-            self.caller,
-            self.base_dir,
-            self.vcs,
-            paths
+            self.caller, self.base_dir, self.vcs, paths
         )
 
         self.structure = [
@@ -620,7 +608,7 @@ class BrowserContextMenu(object):
             (MenuDelete, None),
             (MenuBrowserCopyTo, None),
             (MenuBrowserCopyUrlToClipboard, None),
-            (MenuBrowserMoveTo, None)
+            (MenuBrowserMoveTo, None),
         ]
 
     def show(self):
@@ -630,10 +618,9 @@ class BrowserContextMenu(object):
         context_menu = GtkContextMenu(self.structure, self.conditions, self.callbacks)
         context_menu.show(self.event)
 
-classes_map = {
-    rabbitvcs.vcs.VCS_SVN: SVNBrowser,
-    rabbitvcs.vcs.VCS_DUMMY: SVNBrowser
-}
+
+classes_map = {rabbitvcs.vcs.VCS_SVN: SVNBrowser, rabbitvcs.vcs.VCS_DUMMY: SVNBrowser}
+
 
 def browser_factory(path):
     guess = rabbitvcs.vcs.guess(path)
@@ -642,9 +629,8 @@ def browser_factory(path):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main
-    (options, url) = main(
-        usage="Usage: rabbitvcs browser [url]"
-    )
+
+    (options, url) = main(usage="Usage: rabbitvcs browser [url]")
 
     window = browser_factory(url[0])
     window.register_gtk_quit()
