@@ -1,4 +1,14 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+from rabbitvcs.ui.dialog import MessageBox
+import rabbitvcs.ui.action
+from rabbitvcs.util.strings import S
+from rabbitvcs.util.contextmenuitems import *
+from rabbitvcs.util.contextmenu import GtkContextMenu
+import rabbitvcs.ui.widget
+from rabbitvcs.ui import InterfaceView
+from gi.repository import Gtk, GObject, Gdk
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -26,22 +36,15 @@ import os.path
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk
 sa.restore()
 
-from rabbitvcs.ui import InterfaceView
-import rabbitvcs.ui.widget
-from rabbitvcs.util.contextmenu import GtkContextMenu
-from rabbitvcs.util.contextmenuitems import *
-from rabbitvcs.util.strings import S
-import rabbitvcs.ui.action
-from rabbitvcs.ui.dialog import MessageBox
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
+
 class Changes(InterfaceView):
     """
     Show how files and folders are different between revisions.
@@ -51,38 +54,30 @@ class Changes(InterfaceView):
                 in revisions like HEAD.  Currently, if a revision is passed it
                 assumes it is a number
     """
+
     selected_rows = []
-    MORE_ACTIONS_ITEMS = [
-        _("More Actions..."),
-        _("View unified diff")
-    ]
+    MORE_ACTIONS_ITEMS = [_("More Actions..."), _("View unified diff")]
 
     def __init__(self, path1=None, revision1=None, path2=None, revision2=None):
         InterfaceView.__init__(self, "changes", "Changes")
 
         self.vcs = rabbitvcs.vcs.VCS()
 
-        self.MORE_ACTIONS_CALLBACKS = [
-            None,
-            self.on_more_actions_view_unified_diff
-        ]
+        self.MORE_ACTIONS_CALLBACKS = [None, self.on_more_actions_view_unified_diff]
 
         self.more_actions = rabbitvcs.ui.widget.ComboBox(
-            self.get_widget("more_actions"),
-            self.MORE_ACTIONS_ITEMS
+            self.get_widget("more_actions"), self.MORE_ACTIONS_ITEMS
         )
         self.more_actions.set_active(0)
 
         repo_paths = helper.get_repository_paths()
         self.first_urls = rabbitvcs.ui.widget.ComboBox(
-            self.get_widget("first_urls"),
-            repo_paths
+            self.get_widget("first_urls"), repo_paths
         )
         self.first_urls_browse = self.get_widget("first_urls_browse")
 
         self.second_urls = rabbitvcs.ui.widget.ComboBox(
-            self.get_widget("second_urls"),
-            repo_paths
+            self.get_widget("second_urls"), repo_paths
         )
         self.second_urls_browse = self.get_widget("second_urls_browse")
 
@@ -135,8 +130,9 @@ class Changes(InterfaceView):
         for tup in indexes:
             self.selected_rows.append(tup[0])
 
-        if event.button == 3 and event.type == Gdk.EventType.BUTTON_RELEASE:
-            self.show_changes_table_popup_menu(treeview, event)
+        if not event is None:
+            if event.button == 3 and event.type == Gdk.EventType.BUTTON_RELEASE:
+                self.show_changes_table_popup_menu(treeview, event)
 
     def on_more_actions_changed(self, widget, data=None):
         index = self.more_actions.get_active()
@@ -177,15 +173,14 @@ class Changes(InterfaceView):
         self.check_refresh_button()
 
     def can_first_browse_urls(self):
-        return (self.first_urls.get_active_text() != "")
+        return self.first_urls.get_active_text() != ""
 
     def can_second_browse_urls(self):
-        return (self.second_urls.get_active_text() != "")
+        return self.second_urls.get_active_text() != ""
 
     def check_refresh_button(self):
         can_click_refresh = (
-            self.can_first_browse_urls()
-            and self.can_second_browse_urls()
+            self.can_first_browse_urls() and self.can_second_browse_urls()
         )
 
         self.get_widget("refresh").set_sensitive(can_click_refresh)
@@ -198,7 +193,6 @@ class Changes(InterfaceView):
         can_browse_urls = self.can_second_browse_urls()
         self.second_urls_browse.set_sensitive(can_browse_urls)
 
-
     def enable_more_actions(self):
         self.more_actions.set_sensitive(True)
 
@@ -218,13 +212,15 @@ class Changes(InterfaceView):
             rev1 = self.get_first_revision()
             rev2 = self.get_second_revision()
 
-            helper.launch_ui_window("diff", [
-                "%s@%s" % (url1, S(rev1)),
-                "%s@%s" % (url2, S(rev2)),
-                "%s" % (sidebyside and "-s" or ""),
-                "--vcs=%s" % self.get_vcs_name()
-            ])
-
+            helper.launch_ui_window(
+                "diff",
+                [
+                    "%s@%s" % (url1, S(rev1)),
+                    "%s@%s" % (url2, S(rev2)),
+                    "%s" % (sidebyside and "-s" or ""),
+                    "--vcs=%s" % self.get_vcs_name(),
+                ],
+            )
 
     #
     # More Actions callbacks
@@ -236,11 +232,14 @@ class Changes(InterfaceView):
         rev2 = self.get_second_revision()
         url2 = self.second_urls.get_active_text()
 
-        helper.launch_ui_window("diff", [
-            "%s@%s" % (url1, S(rev1)),
-            "%s@%s" % (url2, S(rev2)),
-            "--vcs=%s" % self.get_vcs_name()
-        ])
+        helper.launch_ui_window(
+            "diff",
+            [
+                "%s@%s" % (url1, S(rev1)),
+                "%s@%s" % (url2, S(rev2)),
+                "--vcs=%s" % self.get_vcs_name(),
+            ],
+        )
 
     def get_vcs_name(self):
         vcs = rabbitvcs.vcs.VCS_DUMMY
@@ -251,6 +250,7 @@ class Changes(InterfaceView):
 
         return vcs
 
+
 class SVNChanges(Changes):
     def __init__(self, path1=None, revision1=None, path2=None, revision2=None):
         Changes.__init__(self, path1, revision1, path2, revision2)
@@ -270,7 +270,7 @@ class SVNChanges(Changes):
             self.svn,
             revision=revision1,
             url_combobox=self.first_urls,
-            expand=True
+            expand=True,
         )
 
         self.second_revision_selector = rabbitvcs.ui.widget.RevisionSelector(
@@ -278,21 +278,15 @@ class SVNChanges(Changes):
             self.svn,
             revision=revision2,
             url_combobox=self.second_urls,
-            expand=True
+            expand=True,
         )
 
         self.changes_table = rabbitvcs.ui.widget.Table(
             self.get_widget("changes_table"),
-            [GObject.TYPE_STRING, GObject.TYPE_STRING,
-                GObject.TYPE_STRING],
+            [GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_STRING],
             [_("Path"), _("Change"), _("Property Change")],
-            flags={
-                "sortable": True,
-                "sort_on": 1
-            },
-            callbacks={
-                "mouse-event":   self.on_changes_table_button_released
-            }
+            flags={"sortable": True, "sort_on": 1},
+            callbacks={"mouse-event": self.on_changes_table_button_released},
         )
 
         self.check_ui()
@@ -306,17 +300,10 @@ class SVNChanges(Changes):
         second_rev = self.get_second_revision()
         second_url = self.second_urls.get_active_text()
 
-        self.action = rabbitvcs.ui.action.SVNAction(
-            self.svn,
-            notification=False
-        )
+        self.action = rabbitvcs.ui.action.SVNAction(self.svn, notification=False)
         self.action.append(self.disable_more_actions)
         self.action.append(
-            self.svn.diff_summarize,
-            first_url,
-            first_rev,
-            second_url,
-            second_rev
+            self.svn.diff_summarize, first_url, first_rev, second_url, second_rev
         )
         self.action.append(helper.save_repository_path, first_url)
         self.action.append(helper.save_repository_path, second_url)
@@ -330,27 +317,30 @@ class SVNChanges(Changes):
 
         self.changes_table.clear()
         for item in summary:
-            prop_changed = (item["prop_changed"] == 1 and _("Yes") or _("No"))
+            prop_changed = item["prop_changed"] == 1 and _("Yes") or _("No")
 
             path = item["path"]
             if path == "":
                 path = "."
 
-            self.changes_table.append([
-                path,
-                str(item["summarize_kind"]),
-                prop_changed
-            ])
+            self.changes_table.append([path, str(item["summarize_kind"]), prop_changed])
 
     def on_first_urls_browse_clicked(self, widget, data=None):
         from rabbitvcs.ui.browser import SVNBrowserDialog
-        SVNBrowserDialog(self.first_urls.get_active_text(),
-            callback=self.on_first_repo_chooser_closed)
+
+        SVNBrowserDialog(
+            self.first_urls.get_active_text(),
+            callback=self.on_first_repo_chooser_closed,
+        )
 
     def on_second_urls_browse_clicked(self, widget, data=None):
         from rabbitvcs.ui.browser import SVNBrowserDialog
-        SVNBrowserDialog(self.second_urls.get_active_text(),
-            callback=self.on_second_repo_chooser_closed)
+
+        SVNBrowserDialog(
+            self.second_urls.get_active_text(),
+            callback=self.on_second_repo_chooser_closed,
+        )
+
 
 class GitChanges(Changes):
     def __init__(self, path1=None, revision1=None, path2=None, revision2=None):
@@ -374,7 +364,7 @@ class GitChanges(Changes):
             self.git,
             revision=revision1,
             url_combobox=self.first_urls,
-            expand=True
+            expand=True,
         )
 
         self.second_revision_selector = rabbitvcs.ui.widget.RevisionSelector(
@@ -382,13 +372,13 @@ class GitChanges(Changes):
             self.git,
             revision=revision2,
             url_combobox=self.second_urls,
-            expand=True
+            expand=True,
         )
 
         self.changes_table = rabbitvcs.ui.widget.Table(
             self.get_widget("changes_table"),
             [GObject.TYPE_STRING, GObject.TYPE_STRING],
-            [_("Path"), _("Change")]
+            [_("Path"), _("Change")],
         )
 
         self.check_ui()
@@ -402,17 +392,10 @@ class GitChanges(Changes):
         second_rev = self.get_second_revision()
         second_url = self.second_urls.get_active_text()
 
-        self.action = rabbitvcs.ui.action.GitAction(
-            self.git,
-            notification=False
-        )
+        self.action = rabbitvcs.ui.action.GitAction(self.git, notification=False)
         self.action.append(self.disable_more_actions)
         self.action.append(
-            self.git.diff_summarize,
-            first_url,
-            first_rev,
-            second_url,
-            second_rev
+            self.git.diff_summarize, first_url, first_rev, second_url, second_rev
         )
         self.action.append(helper.save_repository_path, first_url)
         self.action.append(helper.save_repository_path, second_url)
@@ -426,10 +409,7 @@ class GitChanges(Changes):
 
         self.changes_table.clear()
         for item in summary:
-            self.changes_table.append([
-                item.path,
-                item.action
-            ])
+            self.changes_table.append([item.path, item.action])
 
 
 class MenuOpenFirst(MenuItem):
@@ -437,49 +417,47 @@ class MenuOpenFirst(MenuItem):
     label = _("Open from first revision")
     icon = "document-open"
 
+
 class MenuOpenSecond(MenuItem):
     identifier = "RabbitVCS::Open_Second"
     label = _("Open from second revision")
     icon = "document-open"
 
+
 class MenuViewDiff(MenuItem):
     identifier = "RabbitVCS::View_Diff"
     label = _("View unified diff(s)")
     icon = "rabbitvcs-diff"
 
+
 class MenuCompare(MenuItem):
     identifier = "RabbitVCS::Compare"
     label = _("Compare side by side")
     icon = "rabbitvcs-compare"
 
+
 class ChangesContextMenuConditions(object):
     def __init__(self, caller, vcs):
         self.caller = caller
         self.vcs = vcs
 
     def open_first(self):
-        return (
-            len(self.caller.selected_rows) == 1
-        )
+        return len(self.caller.selected_rows) == 1
 
     def open_second(self):
-        return (
-            len(self.caller.selected_rows) == 1
-            and (
-                str(self.caller.get_first_revision()) != str(self.caller.get_second_revision())
-                or self.caller.first_urls.get_active_text() != self.caller.second_urls.get_active_text()
-            )
+        return len(self.caller.selected_rows) == 1 and (
+            str(self.caller.get_first_revision())
+            != str(self.caller.get_second_revision())
+            or self.caller.first_urls.get_active_text()
+            != self.caller.second_urls.get_active_text()
         )
 
     def view_diff(self):
-        return (
-            len(self.caller.selected_rows) > 0
-        )
+        return len(self.caller.selected_rows) > 0
 
     def compare(self):
-        return (
-            len(self.caller.selected_rows) > 0
-        )
+        return len(self.caller.selected_rows) > 0
+
 
 class ChangesContextMenuCallbacks(object):
     def __init__(self, caller, vcs):
@@ -494,11 +472,9 @@ class ChangesContextMenuCallbacks(object):
         url = helper.url_join(self.caller.first_urls.get_active_text(), path)
         rev = self.caller.get_first_revision()
 
-        helper.launch_ui_window("open", [
-            "--vcs=%s" % self.caller.get_vcs_name(),
-            url,
-            "-r%s" % S(rev)
-        ])
+        helper.launch_ui_window(
+            "open", ["--vcs=%s" % self.caller.get_vcs_name(), url, "-r%s" % S(rev)]
+        )
 
     def open_second(self, widget, data=None):
         path = self.caller.changes_table.get_row(self.caller.selected_rows[0])[0]
@@ -507,11 +483,9 @@ class ChangesContextMenuCallbacks(object):
 
         url = helper.url_join(self.caller.second_urls.get_active_text(), path)
         rev = self.caller.get_second_revision()
-        helper.launch_ui_window("open", [
-            "--vcs=%s" % self.caller.get_vcs_name(),
-            url,
-            "-r%s" % S(rev)
-        ])
+        helper.launch_ui_window(
+            "open", ["--vcs=%s" % self.caller.get_vcs_name(), url, "-r%s" % S(rev)]
+        )
 
     def view_diff(self, widget, data=None):
         self.caller.view_selected_diff()
@@ -529,18 +503,23 @@ class ChangesContextMenuCallbacks(object):
             rev1 = self.caller.get_first_revision()
             rev2 = self.caller.get_second_revision()
 
-            helper.launch_ui_window("diff", [
-                "%s@%s" % (url1, S(rev1)),
-                "%s@%s" % (url2, S(rev2)),
-                "-s",
-                "--vcs=%s" % self.caller.get_vcs_name()
-            ])
+            helper.launch_ui_window(
+                "diff",
+                [
+                    "%s@%s" % (url1, S(rev1)),
+                    "%s@%s" % (url2, S(rev2)),
+                    "-s",
+                    "--vcs=%s" % self.caller.get_vcs_name(),
+                ],
+            )
+
 
 class ChangesContextMenu(object):
     """
     Defines context menu items for a table with files
 
     """
+
     def __init__(self, caller, event):
         """
         @param  caller: The calling object
@@ -552,15 +531,9 @@ class ChangesContextMenu(object):
         self.vcs = rabbitvcs.vcs.VCS()
         self.svn = self.vcs.svn()
 
-        self.conditions = ChangesContextMenuConditions(
-            self.caller,
-            self.vcs
-        )
+        self.conditions = ChangesContextMenuConditions(self.caller, self.vcs)
 
-        self.callbacks = ChangesContextMenuCallbacks(
-            self.caller,
-            self.vcs
-        )
+        self.callbacks = ChangesContextMenuCallbacks(self.caller, self.vcs)
 
         # The first element of each tuple is a key that matches a
         # ContextMenuItems item.  The second element is either None when there
@@ -569,7 +542,7 @@ class ChangesContextMenu(object):
             (MenuOpenFirst, None),
             (MenuOpenSecond, None),
             (MenuViewDiff, None),
-            (MenuCompare, None)
+            (MenuCompare, None),
         ]
 
     def show(self):
@@ -579,10 +552,9 @@ class ChangesContextMenu(object):
         context_menu = GtkContextMenu(self.structure, self.conditions, self.callbacks)
         context_menu.show(self.event)
 
-classes_map = {
-    rabbitvcs.vcs.VCS_SVN: SVNChanges,
-    rabbitvcs.vcs.VCS_GIT: GitChanges
-}
+
+classes_map = {rabbitvcs.vcs.VCS_SVN: SVNChanges, rabbitvcs.vcs.VCS_GIT: GitChanges}
+
 
 def changes_factory(vcs, path1=None, revision1=None, path2=None, revision2=None):
     if not vcs:
@@ -594,9 +566,9 @@ def changes_factory(vcs, path1=None, revision1=None, path2=None, revision2=None)
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main, VCS_OPT
+
     (options, args) = main(
-        [VCS_OPT],
-        usage="Usage: rabbitvcs changes [url1@rev1] [url2@rev2]"
+        [VCS_OPT], usage="Usage: rabbitvcs changes [url1@rev1] [url2@rev2]"
     )
 
     pathrev1 = helper.parse_path_revision_string(args.pop(0))
@@ -604,6 +576,8 @@ if __name__ == "__main__":
     if len(args) > 0:
         pathrev2 = helper.parse_path_revision_string(args.pop(0))
 
-    window = changes_factory(options.vcs, pathrev1[0], pathrev1[1], pathrev2[0], pathrev2[1])
+    window = changes_factory(
+        options.vcs, pathrev1[0], pathrev1[1], pathrev2[0], pathrev2[1]
+    )
     window.register_gtk_quit()
     Gtk.main()
