@@ -1,4 +1,11 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+from rabbitvcs.util.log import Log
+import rabbitvcs.vcs
+from rabbitvcs.ui.action import SVNAction
+from rabbitvcs.ui import InterfaceNonView
+from gi.repository import Gtk, GObject
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -26,21 +33,17 @@ import os.path
 from rabbitvcs.util import helper
 
 from gi import require_version
+
 require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject
 sa.restore()
 
-from rabbitvcs.ui import InterfaceNonView
-from rabbitvcs.ui.action import SVNAction
-import rabbitvcs.vcs
-from rabbitvcs.util.log import Log
 
 log = Log("rabbitvcs.ui.delete")
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
+
 class Delete(InterfaceNonView):
     """
     This class provides a handler to Delete functionality.
@@ -87,6 +90,7 @@ class Delete(InterfaceNonView):
                 for path in unversioned:
                     helper.delete_item(path)
 
+
 class SVNDelete(Delete):
     def __init__(self, paths):
         Delete.__init__(self, paths)
@@ -95,6 +99,7 @@ class SVNDelete(Delete):
         if rabbitvcs.vcs.guess(paths[0])["vcs"] == rabbitvcs.vcs.VCS_SVN:
             self.vcs.svn().remove(paths, **kwargs)
 
+
 class GitDelete(Delete):
     def __init__(self, paths):
         Delete.__init__(self, paths)
@@ -103,10 +108,9 @@ class GitDelete(Delete):
         if rabbitvcs.vcs.guess(paths[0])["vcs"] == rabbitvcs.vcs.VCS_GIT:
             self.vcs.git(paths[0]).remove(paths)
 
-classes_map = {
-    rabbitvcs.vcs.VCS_SVN: SVNDelete,
-    rabbitvcs.vcs.VCS_GIT: GitDelete
-}
+
+classes_map = {rabbitvcs.vcs.VCS_SVN: SVNDelete, rabbitvcs.vcs.VCS_GIT: GitDelete}
+
 
 def delete_factory(paths):
     guess = rabbitvcs.vcs.guess(paths[0])
@@ -115,6 +119,7 @@ def delete_factory(paths):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main
+
     (options, paths) = main(usage="Usage: rabbitvcs delete [path1] [path2] ...")
 
     window = delete_factory(paths)
