@@ -1,4 +1,11 @@
 from __future__ import absolute_import
+from rabbitvcs.util.strings import S
+import rabbitvcs.util.helper
+import rabbitvcs.ui.wraplabel
+import rabbitvcs.ui.widget
+from rabbitvcs.ui import InterfaceView
+from gi.repository import Gtk, GObject, Gdk, Pango
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -24,50 +31,45 @@ from __future__ import absolute_import
 from gettext import gettext as _
 import os.path
 import gi
+
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, GObject, Gdk, Pango
 
-from rabbitvcs.ui import InterfaceView
-import rabbitvcs.ui.widget
-import rabbitvcs.ui.wraplabel
-import rabbitvcs.util.helper
-from rabbitvcs.util.strings import S
 
-ERROR_NOTICE = _("""\
+ERROR_NOTICE = _(
+    """\
 An error has occurred in the RabbitVCS Nautilus extension. Please contact the \
 <a href="%s">RabbitVCS team</a> with the error details listed below:"""
-    % (rabbitvcs.WEBSITE))
+    % (rabbitvcs.WEBSITE)
+)
+
 
 class PreviousMessages(InterfaceView):
     def __init__(self):
         InterfaceView.__init__(self, "dialogs/previous_messages", "PreviousMessages")
 
-        self.message = rabbitvcs.ui.widget.TextView(
-            self.get_widget("prevmes_message")
-        )
+        self.message = rabbitvcs.ui.widget.TextView(self.get_widget("prevmes_message"))
 
         self.message_table = rabbitvcs.ui.widget.Table(
             self.get_widget("prevmes_table"),
             [GObject.TYPE_STRING, GObject.TYPE_STRING],
             [_("Date"), _("Message")],
-            filters=[{
-                "callback": rabbitvcs.ui.widget.long_text_filter,
-                "user_data": {
-                    "column": 1,
-                    "cols": 80
+            filters=[
+                {
+                    "callback": rabbitvcs.ui.widget.long_text_filter,
+                    "user_data": {"column": 1, "cols": 80},
                 }
-            }],
+            ],
             callbacks={
                 "cursor-changed": self.on_prevmes_table_cursor_changed,
-                "row-activated":  self.on_prevmes_table_row_activated
-            }
+                "row-activated": self.on_prevmes_table_row_activated,
+            },
         )
         self.entries = rabbitvcs.util.helper.get_previous_messages()
         if self.entries is None:
             return None
 
         for entry in self.entries:
-            self.message_table.append([entry[0],entry[1]])
+            self.message_table.append([entry[0], entry[1]])
 
         if len(self.entries) > 0:
             self.message.set_text(S(self.entries[0][1]).display())
@@ -101,12 +103,14 @@ class PreviousMessages(InterfaceView):
             selected_message = selection[-1]
             self.message.set_text(S(selected_message).display())
 
+
 class FolderChooser(object):
     def __init__(self):
         self.dialog = Gtk.FileChooserDialog(
-            title = _("Select a Folder"),
-            parent = None,
-            action = Gtk.FileChooserAction.SELECT_FOLDER)
+            title=_("Select a Folder"),
+            parent=None,
+            action=Gtk.FileChooserAction.SELECT_FOLDER,
+        )
         self.dialog.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
         self.dialog.add_button(_("_Select"), Gtk.ResponseType.OK)
         self.dialog.set_default_response(Gtk.ResponseType.OK)
@@ -120,14 +124,22 @@ class FolderChooser(object):
         self.dialog.destroy()
         return returner
 
+
 class Certificate(InterfaceView):
     """
     Provides a dialog to accept/accept_once/deny an ssl certificate
 
     """
 
-    def __init__(self, realm="", host="",
-            issuer="", valid_from="", valid_until="", fingerprint=""):
+    def __init__(
+        self,
+        realm="",
+        host="",
+        issuer="",
+        valid_from="",
+        valid_until="",
+        fingerprint="",
+    ):
 
         InterfaceView.__init__(self, "dialogs/certificate", "Certificate")
 
@@ -155,6 +167,7 @@ class Certificate(InterfaceView):
         self.dialog.destroy()
         return result
 
+
 class Authentication(InterfaceView):
     def __init__(self, realm="", may_save=True):
         InterfaceView.__init__(self, "dialogs/authentication", "Authentication")
@@ -177,9 +190,12 @@ class Authentication(InterfaceView):
         else:
             return (False, "", "", False)
 
+
 class CertAuthentication(InterfaceView):
     def __init__(self, realm="", may_save=True):
-        InterfaceView.__init__(self, "dialogs/cert_authentication", "CertAuthentication")
+        InterfaceView.__init__(
+            self, "dialogs/cert_authentication", "CertAuthentication"
+        )
 
         self.get_widget("certauth_realm").set_label(realm)
         self.get_widget("certauth_save").set_sensitive(may_save)
@@ -197,9 +213,12 @@ class CertAuthentication(InterfaceView):
         else:
             return (False, "", False)
 
+
 class SSLClientCertPrompt(InterfaceView):
     def __init__(self, realm="", may_save=True):
-        InterfaceView.__init__(self, "dialogs/ssl_client_cert_prompt", "SSLClientCertPrompt")
+        InterfaceView.__init__(
+            self, "dialogs/ssl_client_cert_prompt", "SSLClientCertPrompt"
+        )
 
         self.get_widget("sslclientcert_realm").set_label(realm)
         self.get_widget("sslclientcert_save").set_sensitive(may_save)
@@ -223,6 +242,7 @@ class SSLClientCertPrompt(InterfaceView):
         else:
             return (False, "", False)
 
+
 class Property(InterfaceView):
     def __init__(self, name="", value="", recurse=True):
         InterfaceView.__init__(self, "dialogs/property", "Property")
@@ -231,28 +251,27 @@ class Property(InterfaceView):
         self.save_value = value
 
         self.name = rabbitvcs.ui.widget.ComboBox(
-                self.get_widget("property_name"),
-                [   # default svn properties
-                    'svn:author',
-                    'svn:autoversioned',
-                    'svn:date',
-                    'svn:eol-style',
-                    'svn:executable',
-                    'svn:externals',
-                    'svn:ignore',
-                    'svn:keywords',
-                    'svn:log',
-                    'svn:mergeinfo',
-                    'svn:mime-type',
-                    'svn:needs-lock',
-                    'svn:special',
-                    ]
-                )
+            self.get_widget("property_name"),
+            [  # default svn properties
+                "svn:author",
+                "svn:autoversioned",
+                "svn:date",
+                "svn:eol-style",
+                "svn:executable",
+                "svn:externals",
+                "svn:ignore",
+                "svn:keywords",
+                "svn:log",
+                "svn:mergeinfo",
+                "svn:mime-type",
+                "svn:needs-lock",
+                "svn:special",
+            ],
+        )
         self.name.set_child_text(name)
 
         self.value = rabbitvcs.ui.widget.TextView(
-            self.get_widget("property_value"),
-            value
+            self.get_widget("property_value"), value
         )
 
         self.recurse = self.get_widget("property_recurse")
@@ -273,14 +292,14 @@ class Property(InterfaceView):
         self.save_value = self.value.get_text()
         self.save_recurse = self.recurse.get_active()
 
+
 class FileChooser(object):
     def __init__(self, title=_("Select a File"), folder=None):
         self.dialog = Gtk.FileChooserDialog(
-            title = title,
-            parent = None,
-            action = Gtk.FileChooserAction.OPEN)
+            title=title, parent=None, action=Gtk.FileChooserAction.OPEN
+        )
         self.dialog.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
-        self.dialog.add_button(_("_Open"),   Gtk.ResponseType.OK)
+        self.dialog.add_button(_("_Open"), Gtk.ResponseType.OK)
         if folder is not None:
             self.dialog.set_current_folder(folder)
         self.dialog.set_default_response(Gtk.ResponseType.OK)
@@ -293,14 +312,14 @@ class FileChooser(object):
         self.dialog.destroy()
         return returner
 
+
 class FileSaveAs(object):
     def __init__(self, title=_("Save As..."), folder=None):
         self.dialog = Gtk.FileChooserDialog(
-            title = title,
-            parent = None,
-            action = Gtk.FileChooserAction.SAVE)
+            title=title, parent=None, action=Gtk.FileChooserAction.SAVE
+        )
         self.dialog.add_button(_("_Cancel"), Gtk.ResponseType.CANCEL)
-        self.dialog.add_button(_("_Save"),   Gtk.ResponseType.OK)
+        self.dialog.add_button(_("_Save"), Gtk.ResponseType.OK)
         if folder is not None:
             self.dialog.set_current_folder(folder)
         self.dialog.set_default_response(Gtk.ResponseType.OK)
@@ -313,6 +332,7 @@ class FileSaveAs(object):
         self.dialog.destroy()
         return returner
 
+
 class Confirmation(InterfaceView):
     def __init__(self, message=_("Are you sure you want to continue?")):
         InterfaceView.__init__(self, "dialogs/confirmation", "Confirmation")
@@ -326,6 +346,7 @@ class Confirmation(InterfaceView):
 
         return result
 
+
 class MessageBox(InterfaceView):
     def __init__(self, message):
         InterfaceView.__init__(self, "dialogs/message_box", "MessageBox")
@@ -335,12 +356,15 @@ class MessageBox(InterfaceView):
         dialog.run()
         dialog.destroy()
 
+
 class DeleteConfirmation(InterfaceView):
     def __init__(self, path=None):
-        InterfaceView.__init__(self, "dialogs/delete_confirmation", "DeleteConfirmation")
+        InterfaceView.__init__(
+            self, "dialogs/delete_confirmation", "DeleteConfirmation"
+        )
 
         if path:
-            path = "\"%s\"" % os.path.basename(path)
+            path = '"%s"' % os.path.basename(path)
         else:
             path = _("the selected item(s)")
 
@@ -355,6 +379,7 @@ class DeleteConfirmation(InterfaceView):
 
         return result
 
+
 class TextChange(InterfaceView):
     def __init__(self, title=None, message=""):
         InterfaceView.__init__(self, "dialogs/text_change", "TextChange")
@@ -362,8 +387,7 @@ class TextChange(InterfaceView):
             self.get_widget("TextChange").set_title(title)
 
         self.textview = rabbitvcs.ui.widget.TextView(
-            self.get_widget("textchange_message"),
-            message
+            self.get_widget("textchange_message"), message
         )
 
     def run(self):
@@ -374,9 +398,12 @@ class TextChange(InterfaceView):
 
         return (result, self.textview.get_text())
 
+
 class OneLineTextChange(InterfaceView):
     def __init__(self, title=None, label=None, current_text=None):
-        InterfaceView.__init__(self, "dialogs/one_line_text_change", "OneLineTextChange")
+        InterfaceView.__init__(
+            self, "dialogs/one_line_text_change", "OneLineTextChange"
+        )
         if title:
             self.get_widget("OneLineTextChange").set_title(title)
 
@@ -406,19 +433,19 @@ class OneLineTextChange(InterfaceView):
 
         return (result, new_text)
 
+
 class NewFolder(InterfaceView):
     def __init__(self):
         InterfaceView.__init__(self, "dialogs/create_folder", "CreateFolder")
 
         self.folder_name = self.get_widget("folder_name")
         self.textview = rabbitvcs.ui.widget.TextView(
-            self.get_widget("log_message"),
-            _("Added a folder to the repository")
+            self.get_widget("log_message"), _("Added a folder to the repository")
         )
         self.on_folder_name_changed(self.folder_name)
 
     def on_folder_name_changed(self, widget):
-        complete = (widget.get_text() != "")
+        complete = widget.get_text() != ""
         self.get_widget("ok").set_sensitive(complete)
 
     def run(self):
@@ -435,8 +462,8 @@ class NewFolder(InterfaceView):
         else:
             return None
 
-class ErrorNotification(InterfaceView):
 
+class ErrorNotification(InterfaceView):
     def __init__(self, text):
         InterfaceView.__init__(self, "dialogs/error_notification", "ErrorNotification")
 
@@ -448,9 +475,7 @@ class ErrorNotification(InterfaceView):
         notice_box.show_all()
 
         self.textview = rabbitvcs.ui.widget.TextView(
-            self.get_widget("error_text"),
-            text,
-            spellcheck=False
+            self.get_widget("error_text"), text, spellcheck=False
         )
 
         self.textview.view.modify_font(Pango.FontDescription("monospace"))
@@ -459,6 +484,7 @@ class ErrorNotification(InterfaceView):
         dialog.run()
         dialog.destroy()
 
+
 class NameEmailPrompt(InterfaceView):
     def __init__(self):
         InterfaceView.__init__(self, "dialogs/name_email_prompt", "NameEmailPrompt")
@@ -483,9 +509,12 @@ class NameEmailPrompt(InterfaceView):
         else:
             return (None, None)
 
+
 class MarkResolvedPrompt(InterfaceView):
     def __init__(self):
-        InterfaceView.__init__(self, "dialogs/mark_resolved_prompt", "MarkResolvedPrompt")
+        InterfaceView.__init__(
+            self, "dialogs/mark_resolved_prompt", "MarkResolvedPrompt"
+        )
 
     def run(self):
         self.dialog = self.get_widget("MarkResolvedPrompt")
@@ -493,6 +522,7 @@ class MarkResolvedPrompt(InterfaceView):
         self.dialog.destroy()
         return result
 
+
 class ConflictDecision(InterfaceView):
     """
     Provides a dialog to make conflict decisions with.  User can accept mine,
@@ -523,15 +553,14 @@ class ConflictDecision(InterfaceView):
         self.dialog.destroy()
         return result
 
+
 class Loading(InterfaceView):
     def __init__(self):
         InterfaceView.__init__(self, "dialogs/loading", "Loading")
 
         self.get_widget("loading_cancel").set_sensitive(False)
 
-        self.pbar = rabbitvcs.ui.widget.ProgressBar(
-            self.get_widget("pbar")
-        )
+        self.pbar = rabbitvcs.ui.widget.ProgressBar(self.get_widget("pbar"))
         self.pbar.start_pulsate()
 
     def on_destroy(self, widget):
