@@ -1,4 +1,12 @@
 from __future__ import absolute_import
+import six
+from rabbitvcs import gettext
+from rabbitvcs.util.strings import S
+import rabbitvcs.vcs
+from rabbitvcs.ui.action import SVNAction, GitAction
+from rabbitvcs.ui import InterfaceNonView
+from gi.repository import Gtk, GObject, Gdk
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -27,21 +35,14 @@ import os.path
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk
 sa.restore()
 
-from rabbitvcs.ui import InterfaceNonView
-from rabbitvcs.ui.action import SVNAction, GitAction
 
-import rabbitvcs.vcs
-from rabbitvcs.util.strings import S
-
-from rabbitvcs import gettext
 _ = gettext.gettext
 
-import six
 
 class SVNOpen(InterfaceNonView):
     """
@@ -71,20 +72,18 @@ class SVNOpen(InterfaceNonView):
 
         url = path
         if not self.svn.is_path_repository_url(path):
-            url = self.svn.get_repo_root_url(path) + '/' + path
-        dest = helper.get_tmp_path("rabbitvcs-" + revision + "-" + os.path.basename(path))
-
-        self.svn.export(
-            url,
-            dest,
-            revision=revision_obj,
-            force=True
+            url = self.svn.get_repo_root_url(path) + "/" + path
+        dest = helper.get_tmp_path(
+            "rabbitvcs-" + revision + "-" + os.path.basename(path)
         )
 
+        self.svn.export(url, dest, revision=revision_obj, force=True)
+
         helper.open_item(dest)
 
         raise SystemExit()
 
+
 class GitOpen(InterfaceNonView):
     """
     This class provides a handler to open tracked files.
@@ -113,16 +112,12 @@ class GitOpen(InterfaceNonView):
 
         dest_dir = helper.get_tmp_path("rabbitvcs-" + S(revision))
 
-        self.git.export(
-            path,
-            dest_dir,
-            revision=revision_obj
-        )
+        self.git.export(path, dest_dir, revision=revision_obj)
 
         repo_path = self.git.find_repository_path(path)
         relative_path = path
         if path.startswith(repo_path):
-            relative_path = path[len(repo_path)+1:]
+            relative_path = path[len(repo_path) + 1 :]
 
         dest_path = "%s/%s" % (dest_dir, relative_path)
 
@@ -130,10 +125,9 @@ class GitOpen(InterfaceNonView):
 
         raise SystemExit()
 
-classes_map = {
-    rabbitvcs.vcs.VCS_SVN: SVNOpen,
-    rabbitvcs.vcs.VCS_GIT: GitOpen
-}
+
+classes_map = {rabbitvcs.vcs.VCS_SVN: SVNOpen, rabbitvcs.vcs.VCS_GIT: GitOpen}
+
 
 def open_factory(vcs, path, revision):
     if not vcs:
@@ -145,9 +139,9 @@ def open_factory(vcs, path, revision):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main, REVISION_OPT, VCS_OPT
+
     (options, paths) = main(
-        [REVISION_OPT, VCS_OPT],
-        usage="Usage: rabbitvcs open path [-r REVISION]"
+        [REVISION_OPT, VCS_OPT], usage="Usage: rabbitvcs open path [-r REVISION]"
     )
 
     window = open_factory(options.vcs, paths[0], options.revision)
