@@ -1,4 +1,14 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+from rabbitvcs.ui.action import SVNAction
+from rabbitvcs.util.log import Log
+import rabbitvcs.vcs
+from rabbitvcs.util.strings import S
+import rabbitvcs.ui.dialog
+import rabbitvcs.ui.widget
+from rabbitvcs.ui.properties import PropertiesBase
+from gi.repository import Gtk, GObject, Gdk
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -24,24 +34,17 @@ from __future__ import absolute_import
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk
 sa.restore()
 
-from rabbitvcs.ui.properties import PropertiesBase
-import rabbitvcs.ui.widget
-import rabbitvcs.ui.dialog
-from rabbitvcs.util.strings import S
-import rabbitvcs.vcs
-from rabbitvcs.util.log import Log
-from rabbitvcs.ui.action import SVNAction
 
 log = Log("rabbitvcs.ui.revprops")
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
+
 class SVNRevisionProperties(PropertiesBase):
     def __init__(self, path, revision=None):
         PropertiesBase.__init__(self, path)
@@ -63,8 +66,7 @@ class SVNRevisionProperties(PropertiesBase):
         self.table.clear()
         try:
             self.proplist = self.svn.revproplist(
-                self.get_widget("path").get_text(),
-                self.revision_obj
+                self.get_widget("path").get_text(), self.revision_obj
             )
         except Exception as e:
             log.exception(e)
@@ -72,25 +74,17 @@ class SVNRevisionProperties(PropertiesBase):
             self.proplist = {}
 
         if self.proplist:
-            for key,val in list(self.proplist.items()):
-                self.table.append([False, key,val.rstrip()])
+            for key, val in list(self.proplist.items()):
+                self.table.append([False, key, val.rstrip()])
 
     def save(self):
         delete_recurse = self.get_widget("delete_recurse").get_active()
 
-        self.action = SVNAction(
-            self.svn,
-            notification=False,
-            run_in_thread=False
-        )
+        self.action = SVNAction(self.svn, notification=False, run_in_thread=False)
 
         for row in self.delete_stack:
             self.action.append(
-                self.svn.revpropdel,
-                self.path,
-                row[1],
-                self.revision_obj,
-                force=True
+                self.svn.revpropdel, self.path, row[1], self.revision_obj, force=True
             )
 
         for row in self.table.get_items():
@@ -100,7 +94,7 @@ class SVNRevisionProperties(PropertiesBase):
                 row[2],
                 self.path,
                 self.revision_obj,
-                force=True
+                force=True,
             )
 
         self.action.schedule()
@@ -110,10 +104,8 @@ class SVNRevisionProperties(PropertiesBase):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main, VCS_OPT
-    (options, args) = main(
-        [VCS_OPT],
-        usage="Usage: rabbitvcs revprops [url1@rev1]"
-    )
+
+    (options, args) = main([VCS_OPT], usage="Usage: rabbitvcs revprops [url1@rev1]")
 
     pathrev = helper.parse_path_revision_string(args.pop(0))
     window = SVNRevisionProperties(pathrev[0], pathrev[1])
