@@ -1,4 +1,15 @@
 from __future__ import absolute_import
+from rabbitvcs import gettext
+import rabbitvcs.vcs
+import rabbitvcs.util.settings
+from rabbitvcs.util.strings import S
+from rabbitvcs.ui.log import log_dialog_factory
+from rabbitvcs.ui.dialog import DeleteConfirmation
+import rabbitvcs.ui.widget
+from rabbitvcs.ui.action import GitAction
+from rabbitvcs.ui import InterfaceView
+from gi.repository import Gtk, GObject, Gdk, Pango
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -28,26 +39,18 @@ import time
 from rabbitvcs.util import helper
 
 import gi
+
 gi.require_version("Gtk", "3.0")
 sa = helper.SanitizeArgv()
-from gi.repository import Gtk, GObject, Gdk, Pango
 sa.restore()
 
-from rabbitvcs.ui import InterfaceView
-from rabbitvcs.ui.action import GitAction
-import rabbitvcs.ui.widget
-from rabbitvcs.ui.dialog import DeleteConfirmation
-from rabbitvcs.ui.log import log_dialog_factory
-from rabbitvcs.util.strings import S
-import rabbitvcs.util.settings
-import rabbitvcs.vcs
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
 STATE_ADD = 0
 STATE_EDIT = 1
 
+
 class GitTagManager(InterfaceView):
     """
     Provides a UI interface to manage items
@@ -80,18 +83,14 @@ class GitTagManager(InterfaceView):
             [GObject.TYPE_STRING],
             [_("Tag")],
             callbacks={
-                "mouse-event":   self.on_treeview_mouse_event,
-                "key-event":     self.on_treeview_key_event
+                "mouse-event": self.on_treeview_mouse_event,
+                "key-event": self.on_treeview_key_event,
             },
-            flags={
-                "sortable": True,
-                "sort_on": 0
-            }
+            flags={"sortable": True, "sort_on": 0},
         )
         self.initialize_detail()
         self.load(self.show_add)
 
-
     def initialize_detail(self):
         self.detail_container = self.get_widget("detail_container")
 
@@ -102,8 +101,8 @@ class GitTagManager(InterfaceView):
         row = 0
 
         # Set up the Tag line
-        label = Gtk.Label(label = _("Name:"))
-        label.set_properties(xalign=0, yalign=.5)
+        label = Gtk.Label(label=_("Name:"))
+        label.set_properties(xalign=0, yalign=0.5)
         self.tag_entry = Gtk.Entry()
         self.tag_entry.set_hexpand(True)
         self.detail_grid.attach(label, 0, row, 1, 1)
@@ -112,8 +111,8 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the Commit-sha line
-        label = Gtk.Label(label = _("Revision:"))
-        label.set_properties(xalign=0, yalign=.5)
+        label = Gtk.Label(label=_("Revision:"))
+        label.set_properties(xalign=0, yalign=0.5)
         self.start_point_entry = Gtk.Entry()
         self.start_point_entry.set_size_request(300, -1)
         self.start_point_entry.set_hexpand(True)
@@ -131,7 +130,7 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the Log Message Entry line
-        label = Gtk.Label(label = _("Message:"))
+        label = Gtk.Label(label=_("Message:"))
         label.set_properties(xalign=0, yalign=0)
         self.message_entry = rabbitvcs.ui.widget.TextView()
         self.message_entry.view.set_size_request(300, 75)
@@ -157,9 +156,9 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the tagger line
-        label = Gtk.Label(label = _("Tagger:"))
+        label = Gtk.Label(label=_("Tagger:"))
         label.set_properties(xalign=0, yalign=0)
-        self.tagger_label = Gtk.Label(label = "")
+        self.tagger_label = Gtk.Label(label="")
         self.tagger_label.set_properties(xalign=0, yalign=0, selectable=True)
         self.tagger_label.set_hexpand(True)
         self.tagger_label.set_line_wrap(True)
@@ -169,9 +168,9 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the Date line
-        label = Gtk.Label(label = _("Date:"))
+        label = Gtk.Label(label=_("Date:"))
         label.set_properties(xalign=0, yalign=0)
-        self.date_label = Gtk.Label(label = "")
+        self.date_label = Gtk.Label(label="")
         self.date_label.set_properties(xalign=0, yalign=0, selectable=True)
         self.date_label.set_hexpand(True)
         self.detail_grid.attach(label, 0, row, 1, 1)
@@ -180,9 +179,9 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the Revision line
-        label = Gtk.Label(label = _("Revision:"))
+        label = Gtk.Label(label=_("Revision:"))
         label.set_properties(xalign=0, yalign=0)
-        self.revision_label = Gtk.Label(label = "")
+        self.revision_label = Gtk.Label(label="")
         self.revision_label.set_properties(xalign=0, selectable=True)
         self.revision_label.set_hexpand(True)
         self.revision_label.set_line_wrap(True)
@@ -192,9 +191,9 @@ class GitTagManager(InterfaceView):
         row = row + 1
 
         # Set up the Log Message line
-        label = Gtk.Label(label = _("Message:"))
+        label = Gtk.Label(label=_("Message:"))
         label.set_properties(xalign=0, yalign=0)
-        self.message_label = Gtk.Label(label = "")
+        self.message_label = Gtk.Label(label="")
         self.message_label.set_properties(xalign=0, yalign=0, selectable=True)
         self.message_label.set_hexpand(True)
         self.message_label.set_vexpand(True)
@@ -216,11 +215,9 @@ class GitTagManager(InterfaceView):
         message_row = row
         row = row + 1
 
-        self.add_rows = [tag_name_row, message_entry_row,
-            start_point_row, save_row]
+        self.add_rows = [tag_name_row, message_entry_row, start_point_row, save_row]
 
-        self.view_rows = [tag_name_row, tagger_row,
-            date_row, revision_row, message_row]
+        self.view_rows = [tag_name_row, tagger_row, date_row, revision_row, message_row]
 
         self.detail_grid.show()
         self.detail_container.add(self.detail_grid)
@@ -242,7 +239,9 @@ class GitTagManager(InterfaceView):
     def on_delete_clicked(self, widget):
         selected = self.items_treeview.get_selected_row_items(0)
 
-        confirm = rabbitvcs.ui.dialog.Confirmation(_("Are you sure you want to delete %s?" % ", ".join(selected)))
+        confirm = rabbitvcs.ui.dialog.Confirmation(
+            _("Are you sure you want to delete %s?" % ", ".join(selected))
+        )
         result = confirm.run()
 
         if result == Gtk.ResponseType.OK or result == True:
@@ -303,19 +302,22 @@ class GitTagManager(InterfaceView):
         if self.selected_tag:
             self.tag_entry.set_text(S(self.selected_tag.name).display())
             self.revision_label.set_text(S(self.selected_tag.sha).display())
-            self.message_label.set_text(S(self.selected_tag.message).display().rstrip("\n"))
+            self.message_label.set_text(
+                S(self.selected_tag.message).display().rstrip("\n")
+            )
             self.tagger_label.set_text(S(self.selected_tag.tagger).display())
-            self.date_label.set_text(helper.format_datetime(datetime.fromtimestamp(self.selected_tag.tag_time), self.datetime_format))
+            self.date_label.set_text(
+                helper.format_datetime(
+                    datetime.fromtimestamp(self.selected_tag.tag_time),
+                    self.datetime_format,
+                )
+            )
 
             self.show_rows(self.view_rows)
             self.get_widget("detail_label").set_markup(_("<b>Tag Detail</b>"))
 
-
     def on_log_dialog_button_clicked(self, widget):
-        log_dialog_factory(
-            self.path,
-            ok_callback=self.on_log_dialog_closed
-        )
+        log_dialog_factory(self.path, ok_callback=self.on_log_dialog_closed)
 
     def on_log_dialog_closed(self, data):
         if data:
@@ -324,9 +326,9 @@ class GitTagManager(InterfaceView):
 
 if __name__ == "__main__":
     from rabbitvcs.ui import main, REVISION_OPT, VCS_OPT
+
     (options, paths) = main(
-        [REVISION_OPT, VCS_OPT],
-        usage="Usage: rabbitvcs tag-manager path"
+        [REVISION_OPT, VCS_OPT], usage="Usage: rabbitvcs tag-manager path"
     )
 
     window = GitTagManager(paths[0], options.revision)
