@@ -1,5 +1,16 @@
 from __future__ import absolute_import
+from pprint import pformat
+from rabbitvcs.ui import STATUS_EMBLEMS
+from rabbitvcs.util.log import Log
+from rabbitvcs import gettext
+import rabbitvcs.vcs
+from rabbitvcs.util.strings import S
+from rabbitvcs.util._locale import get_locale
+from rabbitvcs.util import helper
+from rabbitvcs.util.decorators import gtk_unsafe
+from gi.repository import Gtk, Gdk, GObject, Pango
 from six.moves import range
+
 #
 # This is an extension to the Nautilus file manager to allow better
 # integration with the Subversion source control system.
@@ -24,48 +35,45 @@ from six.moves import range
 
 import os
 import os.path
-from locale import getlocale, LC_MESSAGES, strxfrm
+from locale import strxfrm
 
 import gi
-gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk, Gdk, GObject, Pango
+
+try:
+    gi.require_version("Gtk", "3.0")
+except:
+    gi.require_version("Gtk", "4.0")
 
 HAS_GTKSPELL = False
 try:
     gi.require_version("GtkSpell", "3.0")
     from gi.repository import GtkSpell
+
     HAS_GTKSPELL = True
 except (ImportError, ValueError):
     pass
 
-from rabbitvcs.util.decorators import gtk_unsafe
-from rabbitvcs.util import helper
-from rabbitvcs.util.strings import S
-import rabbitvcs.vcs
 
-from rabbitvcs import gettext
 _ = gettext.gettext
 
-from rabbitvcs.util.log import Log
 log = Log("rabbitvcs.ui.widget")
 
-from rabbitvcs.ui import STATUS_EMBLEMS
 
-TOGGLE_BUTTON = 'TOGGLE_BUTTON'
-TYPE_PATH = 'TYPE_PATH'
-TYPE_STATUS = 'TYPE_STATUS'
-TYPE_ELLIPSIZED = 'TYPE_ELLIPSIZED'
-TYPE_GRAPH = 'TYPE_GRAPH'
-TYPE_MARKUP = 'TYPE_MARKUP'
-TYPE_HIDDEN = 'TYPE_HIDDEN'
-TYPE_HIDDEN_OBJECT = 'TYPE_HIDDEN_OBJECT'
+TOGGLE_BUTTON = "TOGGLE_BUTTON"
+TYPE_PATH = "TYPE_PATH"
+TYPE_STATUS = "TYPE_STATUS"
+TYPE_ELLIPSIZED = "TYPE_ELLIPSIZED"
+TYPE_GRAPH = "TYPE_GRAPH"
+TYPE_MARKUP = "TYPE_MARKUP"
+TYPE_HIDDEN = "TYPE_HIDDEN"
+TYPE_HIDDEN_OBJECT = "TYPE_HIDDEN_OBJECT"
 
 ELLIPSIZE_COLUMN_CHARS = 20
 
-PATH_ENTRY = 'PATH_ENTRY'
-SEPARATOR = u'\u2015' * 10
+PATH_ENTRY = "PATH_ENTRY"
+SEPARATOR = "\u2015" * 10
+
 
-from pprint import pformat
 def filter_router(model, iter, column, filters):
     """
     Route filter requests for a table's columns.  This function is called for
@@ -115,6 +123,7 @@ def filter_router(model, iter, column, filters):
 
     return row[column]
 
+
 def path_filter(row, column, user_data=None):
     """
     A common filter function that is used in many tables.  Changes the displayed
@@ -143,6 +152,7 @@ def path_filter(row, column, user_data=None):
     else:
         return row[column]
 
+
 def long_text_filter(row, column, user_data=None):
     """
     Uses the format_long_text helper function to trim and prettify some text.
@@ -151,12 +161,12 @@ def long_text_filter(row, column, user_data=None):
 
     cols = user_data["cols"]
 
-
     if text:
         text = helper.format_long_text(text, cols)
 
     return text
 
+
 def git_revision_filter(row, column, user_data=None):
     """
     Only show the first seven characters of a git revision hash
@@ -171,12 +181,15 @@ def git_revision_filter(row, column, user_data=None):
 
     return text
 
+
 def translate_filter(row, column, user_data=None):
     """
     Translates text as needed.
     """
     text = row[column]
-    if text: return _(text)
+    if text:
+        return _(text)
+
 
 def compare_items(model, iter1, iter2, user_data=None):
 
@@ -204,9 +217,19 @@ def compare_items(model, iter1, iter2, user_data=None):
     else:
         return 1
 
+
 class TableBase(object):
-    def __init__(self, treeview, coltypes, colnames, values=[], filters=None,
-                 filter_types=None, callbacks={}, flags={}):
+    def __init__(
+        self,
+        treeview,
+        coltypes,
+        colnames,
+        values=[],
+        filters=None,
+        filter_types=None,
+        callbacks={},
+        flags={},
+    ):
         """
         @type   treeview: Gtk.Treeview
         @param  treeview: The treeview widget to use
@@ -276,8 +299,8 @@ class TableBase(object):
         for name in colnames:
             if coltypes[i] == GObject.TYPE_BOOLEAN:
                 cell = Gtk.CellRendererToggle()
-                cell.set_property('activatable', True)
-                cell.set_property('xalign', 0)
+                cell.set_property("activatable", True)
+                cell.set_property("xalign", 0)
                 cell.connect("toggled", self.toggled_cb, i)
 
                 colname = ""
@@ -297,25 +320,19 @@ class TableBase(object):
                 col = Gtk.TreeViewColumn(name)
 
                 cellpb = Gtk.CellRendererPixbuf()
-                cellpb.set_property('xalign', 0)
-                cellpb.set_property('yalign', 0)
+                cellpb.set_property("xalign", 0)
+                cellpb.set_property("yalign", 0)
                 col.pack_start(cellpb, False)
                 data = None
                 if "file-column-callback" in callbacks:
-                    data = {
-                        "callback": callbacks["file-column-callback"],
-                        "column": i
-                    }
+                    data = {"callback": callbacks["file-column-callback"], "column": i}
                 else:
-                    data = {
-                        "callback": helper.get_node_kind,
-                        "column": i
-                    }
+                    data = {"callback": helper.get_node_kind, "column": i}
                 col.set_cell_data_func(cellpb, self.file_pixbuf, data)
 
                 cell = Gtk.CellRendererText()
-                cell.set_property('xalign', 0)
-                cell.set_property('yalign', 0)
+                cell.set_property("xalign", 0)
+                cell.set_property("yalign", 0)
                 col.pack_start(cell, False)
                 col.set_attributes(cell, text=i)
             elif coltypes[i] == TYPE_STATUS:
@@ -324,8 +341,8 @@ class TableBase(object):
                 col = Gtk.TreeViewColumn(name)
 
                 cellpb = Gtk.CellRendererPixbuf()
-                cellpb.set_property('xalign', 0)
-                cellpb.set_property('yalign', 0)
+                cellpb.set_property("xalign", 0)
+                cellpb.set_property("yalign", 0)
 
                 col.pack_start(cellpb, False)
 
@@ -334,8 +351,8 @@ class TableBase(object):
                 col.set_cell_data_func(cellpb, self.status_pixbuf, i)
 
                 cell = Gtk.CellRendererText()
-                cell.set_property('xalign', 0)
-                cell.set_property('yalign', 0)
+                cell.set_property("xalign", 0)
+                cell.set_property("yalign", 0)
                 col.pack_start(cell, False)
                 col.set_attributes(cell, text=i)
             elif coltypes[i] == TYPE_HIDDEN:
@@ -349,10 +366,10 @@ class TableBase(object):
             elif coltypes[i] == TYPE_ELLIPSIZED:
                 coltypes[i] = str
                 cell = Gtk.CellRendererText()
-                cell.set_property('yalign', 0)
-                cell.set_property('xalign', 0)
-                cell.set_property('ellipsize', Pango.EllipsizeMode.END)
-                cell.set_property('width-chars', ELLIPSIZE_COLUMN_CHARS)
+                cell.set_property("yalign", 0)
+                cell.set_property("xalign", 0)
+                cell.set_property("ellipsize", Pango.EllipsizeMode.END)
+                cell.set_property("width-chars", ELLIPSIZE_COLUMN_CHARS)
                 col = Gtk.TreeViewColumn(name, cell)
                 col.set_attributes(cell, text=i)
             elif coltypes[i] == TYPE_GRAPH:
@@ -362,10 +379,10 @@ class TableBase(object):
                 col.add_attribute(cell, "graph", i)
             else:
                 cell = Gtk.CellRendererText()
-                cell.set_property('yalign', 0)
-                cell.set_property('xalign', 0)
+                cell.set_property("yalign", 0)
+                cell.set_property("xalign", 0)
                 if i in flags["editable"]:
-                    cell.set_property('editable', True)
+                    cell.set_property("editable", True)
                     cell.connect("edited", self.__cell_edited, i)
 
                 if coltypes[i] == TYPE_MARKUP:
@@ -393,12 +410,8 @@ class TableBase(object):
         # The filter is there to change the way data is displayed. The data
         # should always be accessed via self.data, NOT self.filter.
         self.filter = self.data.filter_new()
-        types = (filter_types and filter_types or coltypes)
-        self.filter.set_modify_func(
-                        types,
-                        filter_router,
-                        filters)
-
+        types = filter_types and filter_types or coltypes
+        self.filter.set_modify_func(types, filter_router, filters)
 
         # This runs through the columns, and sets the "compare_items" comparator
         # as needed. Note that the user data tells which column to sort on.
@@ -408,9 +421,7 @@ class TableBase(object):
             self.sorted.set_default_sort_func(compare_items, None)
 
             for idx in range(0, i):
-                self.sorted.set_sort_func(idx,
-                                          compare_items,
-                                          (idx, coltypes[idx]))
+                self.sorted.set_sort_func(idx, compare_items, (idx, coltypes[idx]))
 
             self.sorted.set_sort_column_id(flags["sort_on"], Gtk.SortType.ASCENDING)
 
@@ -421,7 +432,6 @@ class TableBase(object):
         else:
             self.treeview.set_model(self.data)
 
-
         if len(values) > 0:
             self.populate(values)
 
@@ -454,7 +464,6 @@ class TableBase(object):
             path = self.filter.convert_child_path_to_path(real_path)
         return path
 
-
     def _realpath(self, visible_path):
         """
         Converts a path (ie. row number) that we get from what the user selects
@@ -686,8 +695,8 @@ class TableBase(object):
         if "cell-edited" in self.callbacks:
             self.callbacks["cell-edited"](cell, row, data, column)
 
-#    def __column_header_clicked(self, column, column_idx):
-#        self.data.set_sort_column_id(column_idx, )
+    #    def __column_header_clicked(self, column, column_idx):
+    #        self.data.set_sort_column_id(column_idx, )
 
     def status_pixbuf(self, column, cell, model, iter, colnum):
 
@@ -704,7 +713,6 @@ class TableBase(object):
 
         cell.set_property("icon-name", icon)
 
-
     def file_pixbuf(self, column, cell, model, iter, data=None):
         icon_name = None
 
@@ -731,10 +739,28 @@ class Table(TableBase):
 
     """
 
-    def __init__(self, treeview, coltypes, colnames, values=[], filters=None,
-            filter_types=None, callbacks={}, flags={}):
-        TableBase.__init__(self, treeview, coltypes, colnames, values, filters,
-            filter_types, callbacks, flags)
+    def __init__(
+        self,
+        treeview,
+        coltypes,
+        colnames,
+        values=[],
+        filters=None,
+        filter_types=None,
+        callbacks={},
+        flags={},
+    ):
+        TableBase.__init__(
+            self,
+            treeview,
+            coltypes,
+            colnames,
+            values,
+            filters,
+            filter_types,
+            callbacks,
+            flags,
+        )
 
     def get_store(self, coltypes):
         return Gtk.ListStore(*coltypes)
@@ -769,10 +795,29 @@ class Tree(TableBase):
     See the TableBase documentation for parameter information
 
     """
-    def __init__(self, treeview, coltypes, colnames, values=[], filters=None,
-            filter_types=None, callbacks={}, flags={}):
-        TableBase.__init__(self, treeview, coltypes, colnames, values, filters,
-            filter_types, callbacks, flags)
+
+    def __init__(
+        self,
+        treeview,
+        coltypes,
+        colnames,
+        values=[],
+        filters=None,
+        filter_types=None,
+        callbacks={},
+        flags={},
+    ):
+        TableBase.__init__(
+            self,
+            treeview,
+            coltypes,
+            colnames,
+            values,
+            filters,
+            filter_types,
+            callbacks,
+            flags,
+        )
 
     def get_store(self, coltypes):
         return Gtk.TreeStore(*coltypes)
@@ -794,13 +839,23 @@ class Box(object):
             box.set_column_spacing(spacing)
         self.middle = 0
         # Determine pack start/end indexes.
-        ch = [(box.child_get_property(c, "left-attach"),
-               box.child_get_property(c, "width")) for c in box.get_children()]
-        cv = [(box.child_get_property(c, "top-attach"),
-              box.child_get_property(c, "height")) for c in box.get_children()]
+        ch = [
+            (
+                box.child_get_property(c, "left-attach"),
+                box.child_get_property(c, "width"),
+            )
+            for c in box.get_children()
+        ]
+        cv = [
+            (
+                box.child_get_property(c, "top-attach"),
+                box.child_get_property(c, "height"),
+            )
+            for c in box.get_children()
+        ]
         if ch:
-            ch.sort(key = lambda x: x[0])
-            cv.sort(key = lambda x: x[0])
+            ch.sort(key=lambda x: x[0])
+            cv.sort(key=lambda x: x[0])
             if ch[-1][0] - ch[0][0] > 0:
                 vertical = False
             elif cv[-1][0] - cv[0][0] > 0:
@@ -820,13 +875,19 @@ class Box(object):
         self.attach = lambda child, pos: self.box.attach(child, pos, 0, 1, 1)
         self.set_expand = lambda child, expand: child.set_hexpand(expand)
         self.set_align = lambda child, align: child.set_halign(align)
-        self.set_padding = lambda child, padding: (child.set_margin_start(padding), child.set_margin_end(padding))
+        self.set_padding = lambda child, padding: (
+            child.set_margin_start(padding),
+            child.set_margin_end(padding),
+        )
         if vertical:
             self.insert = self.box.insert_row
             self.attach = lambda child, pos: self.box.attach(child, 0, pos, 1, 1)
             self.set_expand = lambda child, expand: child.set_vexpand(expand)
             self.set_align = lambda child, align: child.set_valign(align)
-            self.set_padding = lambda child, padding: (child.set_margin_top(padding), child.set_margin_bottom(padding))
+            self.set_padding = lambda child, padding: (
+                child.set_margin_top(padding),
+                child.set_margin_bottom(padding),
+            )
 
     def add(self, child):
         if isinstance(child, Box):
@@ -855,6 +916,7 @@ class Box(object):
     def __getattr__(self, name):
         return getattr(self.box, name)
 
+
 class ComboBox(object):
     def __init__(self, cb, items=None, columns=1, textcolumn=0):
 
@@ -872,7 +934,7 @@ class ComboBox(object):
 
         self.cell = Gtk.CellRendererText()
         self.cb.pack_start(self.cell, True)
-        self.cb.add_attribute(self.cell, 'text', textcolumn)
+        self.cb.add_attribute(self.cell, "text", textcolumn)
 
     def append(self, item):
         if not isinstance(item, list):
@@ -911,6 +973,7 @@ class ComboBox(object):
     def set_child_signal(self, signal, callback, userdata=None):
         self.cb.get_child().connect(signal, callback, userdata)
 
+
 class TextView(object):
     def __init__(self, widget=None, value="", spellcheck=True):
         if widget is None:
@@ -925,9 +988,9 @@ class TextView(object):
             try:
                 checker = GtkSpell.Checker()
                 try:
-                    checker.set_language(getlocale(LC_MESSAGES)[0])
+                    checker.set_language(get_locale()[0])
                 except:
-                    checker = None          # Language not available.
+                    checker = None  # Language not available.
                 if checker:
                     checker.attach(self.view)
             except Exception as e:
@@ -935,9 +998,7 @@ class TextView(object):
 
     def get_text(self):
         return self.buffer.get_text(
-            self.buffer.get_start_iter(),
-            self.buffer.get_end_iter(),
-            True
+            self.buffer.get_start_iter(), self.buffer.get_end_iter(), True
         )
 
     @gtk_unsafe
@@ -948,6 +1009,7 @@ class TextView(object):
     def append_text(self, text):
         self.buffer.set_text(S(self.get_text() + text).display())
 
+
 class ProgressBar(object):
     def __init__(self, pbar):
         if pbar is None:
@@ -1024,8 +1086,7 @@ class Clickable(object):
             self._signals[self._2BUTTON_PRESS] = self._signal_data(func, args)
         elif signal == "triple-click":
             self._signals[self._3BUTTON_PRESS] = self._signal_data(func, args)
-        elif signal in ("long-click",
-                        "button-press-event", "button-release-event"):
+        elif signal in ("long-click", "button-press-event", "button-release-event"):
             self._signals[signal] = self._signal_data(func, args)
         else:
             self.widget.connect(signal, func, *args)
@@ -1089,9 +1150,17 @@ class RevisionSelector(object):
 
     """
 
-    def __init__(self, container, client, revision=None,
-            url_combobox=None, url_entry=None, url=None, expand=False,
-            revision_changed_callback=None):
+    def __init__(
+        self,
+        container,
+        client,
+        revision=None,
+        url_combobox=None,
+        url_entry=None,
+        url=None,
+        expand=False,
+        revision_changed_callback=None,
+    ):
         """
         @type   container: A Gtk container object (i.e. HBox, VBox, Box)
         @param  container: The container that to add this widget
@@ -1123,23 +1192,16 @@ class RevisionSelector(object):
         self.url = url
         self.revision_changed_callback = revision_changed_callback
         self.revision_change_inprogress = False
-        hbox = Box(spacing = 4)
+        hbox = Box(spacing=4)
         hbox.set_hexpand(expand)
 
         if self.url_combobox:
             self.url_combobox.cb.connect("changed", self.__on_url_combobox_changed)
 
         if client.vcs == rabbitvcs.vcs.VCS_GIT:
-            self.OPTIONS = [
-                _("HEAD"),
-                _("Revision"),
-                _("Branch")
-            ]
+            self.OPTIONS = [_("HEAD"), _("Revision"), _("Branch")]
         elif client.vcs == rabbitvcs.vcs.VCS_SVN:
-            self.OPTIONS = [
-                _("HEAD"),
-                _("Number")
-            ]
+            self.OPTIONS = [_("HEAD"), _("Number")]
             if not client.is_path_repository_url(self.get_url()):
                 self.OPTIONS.append(_("Working Copy"))
 
@@ -1154,10 +1216,11 @@ class RevisionSelector(object):
 
         self.branch_selector = None
         if client.vcs == rabbitvcs.vcs.VCS_GIT:
-            self.branch_selector = GitBranchSelector(hbox, client, self.__branch_selector_changed)
+            self.branch_selector = GitBranchSelector(
+                hbox, client, self.__branch_selector_changed
+            )
             self.branch_selector.hide()
 
-
         self.revision_browse = Gtk.Button()
         revision_browse_image = Gtk.Image()
         revision_browse_image.set_from_icon_name("edit-find", Gtk.IconSize.MENU)
@@ -1180,6 +1243,7 @@ class RevisionSelector(object):
 
     def __revision_browse_clicked(self, widget):
         from rabbitvcs.ui.log import SVNLogDialog, GitLogDialog
+
         if self.client.vcs == rabbitvcs.vcs.VCS_GIT:
             GitLogDialog(self.get_url(), ok_callback=self.__log_closed)
         elif self.client.vcs == rabbitvcs.vcs.VCS_SVN:
@@ -1310,6 +1374,7 @@ class RevisionSelector(object):
     def __branch_selector_changed(self, branch):
         self.__revision_entry_changed(self.revision_entry)
 
+
 class KeyValueTable(Gtk.Grid):
     """
     Simple extension of a GTK grid to display a two-column table of information
@@ -1330,13 +1395,13 @@ class KeyValueTable(Gtk.Grid):
             row = 0
 
             for key, value in stuff:
-                label_key = Gtk.Label(label = "<b>%s:</b>" % key)
+                label_key = Gtk.Label(label="<b>%s:</b>" % key)
                 label_key.set_properties(xalign=0, use_markup=True)
 
-                label_value = Gtk.Label(label = "%s" % value)
-                label_value.set_properties(xalign=0,                    \
-                                           ellipsize=Pango.EllipsizeMode.MIDDLE, \
-                                           selectable=True)
+                label_value = Gtk.Label(label="%s" % value)
+                label_value.set_properties(
+                    xalign=0, ellipsize=Pango.EllipsizeMode.MIDDLE, selectable=True
+                )
                 label_value.set_hexpand(True)
                 label_value.set_halign(Gtk.Align.START)
 
@@ -1351,6 +1416,7 @@ class KeyValueTable(Gtk.Grid):
         self.set_column_spacing(self.default_col_spacing)
         self.set_row_spacing(self.default_row_spacing)
 
+
 class GitRepositorySelector(object):
     def __init__(self, container, git, changed_callback=None):
         self.git = git
@@ -1361,36 +1427,20 @@ class GitRepositorySelector(object):
         grid.set_column_spacing(6)
         grid.set_hexpand(True)
 
-        # Set up the Repository Line
-        label = Gtk.Label(label = _("Repository:"))
-        label.set_justify(Gtk.Justification.LEFT)
-        label.set_halign(Gtk.Align.START)
-
-        tmp_repos = []
-        for item in self.git.remote_list():
-            tmp_repos.append(item["name"])
-        self.repository_opt = ComboBox(Gtk.ComboBoxText.new_with_entry(), tmp_repos)
-        self.repository_opt.set_active(0)
-        self.repository_opt.cb.connect("changed", self.__repository_changed)
-        self.repository_opt.cb.set_size_request(175, -1)
-        self.repository_opt.cb.set_hexpand(True)
-
-        grid.attach(label, 0, 0, 1, 1)
-        grid.attach(self.repository_opt.cb, 1, 0, 1, 1)
-
         # Set up the Branch line
-        label = Gtk.Label(label = _("Branch:"))
+        label = Gtk.Label(label=_("Branch:"))
         label.set_justify(Gtk.Justification.LEFT)
         label.set_halign(Gtk.Align.START)
 
         tmp_branches = []
         active_branch_index = 0
         index = 0
-        for item in self.git.branch_list():
+        for item in self.git.local_branch_list():
             tmp_branches.append(item.name)
 
             if item.tracking:
                 active_branch_index = index
+                active_remote = item.upstream
 
             index += 1
 
@@ -1403,8 +1453,33 @@ class GitRepositorySelector(object):
         grid.attach(label, 0, 1, 1, 1)
         grid.attach(self.branch_opt.cb, 1, 1, 1, 1)
 
+        # Set up the Repository Line
+        label = Gtk.Label(label=_("Repository:"))
+        label.set_justify(Gtk.Justification.LEFT)
+        label.set_halign(Gtk.Align.START)
+
+        tmp_repos = []
+        active_remote_index = 0
+        index = 0
+        for item in self.git.remote_list():
+            if item["name"] == active_remote:
+                active_remote_index = index
+
+            index += 1
+
+            tmp_repos.append(item["name"])
+
+        self.repository_opt = ComboBox(Gtk.ComboBoxText.new_with_entry(), tmp_repos)
+        self.repository_opt.set_active(active_remote_index)
+        self.repository_opt.cb.connect("changed", self.__repository_changed)
+        self.repository_opt.cb.set_size_request(175, -1)
+        self.repository_opt.cb.set_hexpand(True)
+
+        grid.attach(label, 0, 0, 1, 1)
+        grid.attach(self.repository_opt.cb, 1, 0, 1, 1)
+
         # Set up the Host line
-        label = Gtk.Label(label = _("Host:"))
+        label = Gtk.Label(label=_("Host:"))
         label.set_justify(Gtk.Justification.LEFT)
         label.set_halign(Gtk.Align.START)
         self.host = Gtk.Label()
@@ -1423,25 +1498,32 @@ class GitRepositorySelector(object):
     def __update_host(self):
         repo = self.repository_opt.get_active_text()
         try:
-            self.host.set_text(S(self.git.config_get(("remote", repo), "url")).display())
+            self.host.set_text(
+                S(self.git.config_get(("remote", repo), "url")).display()
+            )
         except KeyError as e:
             log.error("Missing remote %s config key" % repo)
 
     def __repository_changed(self, repository_opt):
         if self.changed_callback:
-            self.changed_callback(repository_opt.get_active_text(), self.branch_opt.get_active_text())
+            self.changed_callback(
+                repository_opt.get_active_text(), self.branch_opt.get_active_text()
+            )
         self.__update_host()
 
     def __branch_changed(self, branch_opt):
         if self.changed_callback:
-            self.changed_callback(self.repository_opt.get_active_text(), self.branch_opt.get_active_text())
+            self.changed_callback(
+                self.repository_opt.get_active_text(), self.branch_opt.get_active_text()
+            )
+
 
 class GitBranchSelector(object):
     def __init__(self, container, git, changed_callback=None):
         self.git = git
         self.changed_callback = changed_callback
 
-        self.vbox = Box(vertical = True, spacing = 4)
+        self.vbox = Box(vertical=True, spacing=4)
 
         tmp_branches = []
         active = 0
@@ -1479,12 +1561,21 @@ class GitBranchSelector(object):
     def hide(self):
         self.vbox.hide()
 
+
 class MultiFileTextEditor(object):
     """
     Edit a set of text/config/ignore files
     """
 
-    def __init__(self, container, label, combobox_labels, combobox_paths, show_add_line=True, line_content=""):
+    def __init__(
+        self,
+        container,
+        label,
+        combobox_labels,
+        combobox_paths,
+        show_add_line=True,
+        line_content="",
+    ):
         self.container = container
         self.label = label
         self.combobox_labels = combobox_labels
@@ -1506,7 +1597,7 @@ class MultiFileTextEditor(object):
         grid.set_hexpand(True)
         grid.set_vexpand(True)
 
-        combo_label = Gtk.Label(label = label)
+        combo_label = Gtk.Label(label=label)
         combo_label.set_alignment(0, 0.5)
         scrolled_window = Gtk.ScrolledWindow()
         scrolled_window.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
@@ -1520,7 +1611,7 @@ class MultiFileTextEditor(object):
         grid.attach(self.combobox.cb, 1, 0, 2, 1)
 
         if show_add_line:
-            add_label = Gtk.Label(label = _("Add line:"))
+            add_label = Gtk.Label(label=_("Add line:"))
             add_label.set_alignment(0, 0.5)
             self.add_entry = Gtk.Entry()
             self.add_entry.set_text(S(line_content).display())
