@@ -1,4 +1,5 @@
 from __future__ import absolute_import
+
 #
 # command.py
 #
@@ -17,6 +18,7 @@ from rabbitvcs.util.strings import *
 def notify_func(data):
     pass
 
+
 def cancel_func():
     return False
 
@@ -47,18 +49,20 @@ class GittyupCommand(object):
 
     def execute(self):
         env = os.environ.copy()
-        env["LANG"] = "C";
+        env["LANG"] = "C"
         env["PYTHONIOENCODING"] = "UTF-8"
         env["GIT_TERMINAL_PROMPT"] = "0"
         env["GIT_SSL_CERT_PASSWORD_PROTECTED"] = ""
-        proc = subprocess.Popen(self.command,
-                                cwd=self.cwd,
-                                stdin=None,
-                                stderr=subprocess.STDOUT,
-                                stdout=subprocess.PIPE,
-                                env=env,
-                                close_fds=True,
-                                preexec_fn=os.setsid)
+        proc = subprocess.Popen(
+            self.command,
+            cwd=self.cwd,
+            stdin=None,
+            stderr=subprocess.STDOUT,
+            stdout=subprocess.PIPE,
+            env=env,
+            close_fds=True,
+            preexec_fn=os.setsid,
+        )
 
         out = codecs.getreader(UTF8_ENCODING)(proc.stdout, SURROGATE_ESCAPE)
         stdout = []
@@ -66,9 +70,9 @@ class GittyupCommand(object):
         while True:
             line = out.readline()
 
-            if line == '':
+            if line == "":
                 break
-            line = line.rstrip("\r\n") # Strip trailing newline.
+            line = line.rstrip("\r\n")  # Strip trailing newline.
             self.notify(line)
             stdout.append(line)
 
