@@ -6,6 +6,7 @@
 class GittyupStatus(object):
     path = None
     is_staged = False
+
     def __init__(self, path):
         self.path = path
 
@@ -13,39 +14,50 @@ class GittyupStatus(object):
         return "<Status %s %s>" % (self.path, self.identifier)
 
     def __eq__(self, other):
-        return (self.identifier == other.identifier)
+        return self.identifier == other.identifier
+
 
 class NormalStatus(GittyupStatus):
     identifier = "normal"
 
+
 class AddedStatus(GittyupStatus):
     identifier = "added"
 
+
 class RenamedStatus(GittyupStatus):
     identifier = "renamed"
 
+
 class RemovedStatus(GittyupStatus):
     identifier = "removed"
 
+
 class ModifiedStatus(GittyupStatus):
     identifier = "modified"
 
+
 class KilledStatus(GittyupStatus):
     identifier = "killed"
 
+
 class UntrackedStatus(GittyupStatus):
     identifier = "untracked"
 
+
 class MissingStatus(GittyupStatus):
     identifier = "missing"
 
+
 class IgnoredStatus(GittyupStatus):
     identifier = "ignored"
 
+
 class NoStatus(GittyupStatus):
     identifier = ""
+
     def __eq__(self, other):
-        return (self.path == other.path)
+        return self.path == other.path
 
 
 class GittyupObject(object):
@@ -53,6 +65,7 @@ class GittyupObject(object):
         self.sha = sha
         self.obj = obj
 
+
 class Commit(GittyupObject):
     def __init__(self, sha, obj, changed_paths=[]):
         self.sha = sha
@@ -101,6 +114,7 @@ class Commit(GittyupObject):
     def __eq__(self, other):
         return self.sha == other.sha
 
+
 class Tag(GittyupObject):
     def __repr__(self):
         return "<Tag %s>" % self.sha
@@ -129,6 +143,7 @@ class Tag(GittyupObject):
     def tag_timezone(self):
         return self.obj.tag_timezone
 
+
 class CommitTag(Commit):
     def __init__(self, name, sha, obj):
         self._name = name
@@ -143,7 +158,7 @@ class CommitTag(Commit):
         return self._name
 
     def __eq__(self, other):
-        return (self.name == other)
+        return self.name == other
 
     @property
     def tag_type(self):
@@ -165,10 +180,12 @@ class CommitTag(Commit):
     def tag_timezone(self):
         return self.obj.commit_timezone
 
+
 class Tree(GittyupObject):
     def __repr__(self):
         return "<Tree %s>" % self.sha
 
+
 class Branch(Commit):
     def __init__(self, name, sha, obj):
         self._name = name
@@ -183,4 +200,4 @@ class Branch(Commit):
         return self._name
 
     def __eq__(self, other):
-        return (self.name == other)
+        return self.name == other
