@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 from __future__ import print_function
+
 #
 # test/stage.py
 #
@@ -25,7 +26,9 @@ if options.cleanup:
     print("commit.py clean")
 else:
     if os.path.isdir(DIR):
-        raise SystemExit("This test script has already been run.  Please call this script with --cleanup to start again")
+        raise SystemExit(
+            "This test script has already been run.  Please call this script with --cleanup to start again"
+        )
 
     os.mkdir(DIR)
     g = GittyupClient()
@@ -34,11 +37,11 @@ else:
     touch(DIR + "/test1.txt")
     touch(DIR + "/test2.txt")
 
-    g.stage([DIR+"/test1.txt", DIR+"/test2.txt"])
+    g.stage([DIR + "/test1.txt", DIR + "/test2.txt"])
     g.commit("First commit", commit_all=True)
 
     change(DIR + "/test1.txt")
-    g.stage([DIR+"/test1.txt"])
+    g.stage([DIR + "/test1.txt"])
     g.commit("Second commit", author="Alex Plumb <alexplumb@gmail.com>")
 
     print("commit.py pass")
