@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 from __future__ import print_function
+
 #
 # test/pull.py
 #
@@ -24,7 +25,9 @@ if options.cleanup:
     print("pull.py clean")
 else:
     if os.path.isdir(DIR):
-        raise SystemExit("This test script has already been run.  Please call this script with --cleanup to start again")
+        raise SystemExit(
+            "This test script has already been run.  Please call this script with --cleanup to start again"
+        )
 
     g = GittyupClient(DIR, create=True)
     g.remote_add("origin", "git://github.com/adamplumb/gittyup.git")
