@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 from __future__ import print_function
+
 #
 # test/remote.py
 #
@@ -24,19 +25,21 @@ if options.cleanup:
     print("remote.py clean")
 else:
     if os.path.isdir(DIR):
-        raise SystemExit("This test script has already been run.  Please call this script with --cleanup to start again")
+        raise SystemExit(
+            "This test script has already been run.  Please call this script with --cleanup to start again"
+        )
 
     os.mkdir(DIR)
     g = GittyupClient(DIR, create=True)
     g.remote_add("origin", "git://github.com/adamplumb/sprout.git")
     l = g.remote_list()
 
-    assert (len(l) == 1)
-    assert (l[0]["host"] == "git://github.com/adamplumb/sprout.git")
+    assert len(l) == 1
+    assert l[0]["host"] == "git://github.com/adamplumb/sprout.git"
 
     g.remote_delete("origin")
     l = g.remote_list()
 
-    assert (len(l) == 0)
+    assert len(l) == 0
 
     print("remote.py pass")
